from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RichText - Layer 181
RichText = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.TextAnchor,
            pydantic.Tag('TextAnchor')
        ],
        typing.Annotated[
            types.TextBold,
            pydantic.Tag('TextBold')
        ],
        typing.Annotated[
            types.TextConcat,
            pydantic.Tag('TextConcat')
        ],
        typing.Annotated[
            types.TextEmail,
            pydantic.Tag('TextEmail')
        ],
        typing.Annotated[
            types.TextEmpty,
            pydantic.Tag('TextEmpty')
        ],
        typing.Annotated[
            types.TextFixed,
            pydantic.Tag('TextFixed')
        ],
        typing.Annotated[
            types.TextImage,
            pydantic.Tag('TextImage')
        ],
        typing.Annotated[
            types.TextItalic,
            pydantic.Tag('TextItalic')
        ],
        typing.Annotated[
            types.TextMarked,
            pydantic.Tag('TextMarked')
        ],
        typing.Annotated[
            types.TextPhone,
            pydantic.Tag('TextPhone')
        ],
        typing.Annotated[
            types.TextPlain,
            pydantic.Tag('TextPlain')
        ],
        typing.Annotated[
            types.TextStrike,
            pydantic.Tag('TextStrike')
        ],
        typing.Annotated[
            types.TextSubscript,
            pydantic.Tag('TextSubscript')
        ],
        typing.Annotated[
            types.TextSuperscript,
            pydantic.Tag('TextSuperscript')
        ],
        typing.Annotated[
            types.TextUnderline,
            pydantic.Tag('TextUnderline')
        ],
        typing.Annotated[
            types.TextUrl,
            pydantic.Tag('TextUrl')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Reactions - Layer 181
Reactions = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.Reactions,
            pydantic.Tag('messages.Reactions'),
            pydantic.Tag('Reactions')
        ],
        typing.Annotated[
            types.messages.ReactionsNotModified,
            pydantic.Tag('messages.ReactionsNotModified'),
            pydantic.Tag('ReactionsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MediaAreaSuggestedReaction(BaseModel):
    """
    types.MediaAreaSuggestedReaction
    ID: 0x14455871
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MediaAreaSuggestedReaction', 'MediaAreaSuggestedReaction'] = pydantic.Field(
        'types.MediaAreaSuggestedReaction',
        alias='_'
    )

    coordinates: "base.MediaAreaCoordinates"
    reaction: "base.Reaction"
    dark: typing.Optional[bool] = None
    flipped: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UninstallStickerSet(BaseModel):
    """
    functions.messages.UninstallStickerSet
    ID: 0xf96e55de
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.UninstallStickerSet', 'UninstallStickerSet'] = pydantic.Field(
        'functions.messages.UninstallStickerSet',
        alias='_'
    )

    stickerset: "base.InputStickerSet"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessagesFilter - Layer 181
MessagesFilter = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputMessagesFilterChatPhotos,
            pydantic.Tag('InputMessagesFilterChatPhotos')
        ],
        typing.Annotated[
            types.InputMessagesFilterContacts,
            pydantic.Tag('InputMessagesFilterContacts')
        ],
        typing.Annotated[
            types.InputMessagesFilterDocument,
            pydantic.Tag('InputMessagesFilterDocument')
        ],
        typing.Annotated[
            types.InputMessagesFilterEmpty,
            pydantic.Tag('InputMessagesFilterEmpty')
        ],
        typing.Annotated[
            types.InputMessagesFilterGeo,
            pydantic.Tag('InputMessagesFilterGeo')
        ],
        typing.Annotated[
            types.InputMessagesFilterGif,
            pydantic.Tag('InputMessagesFilterGif')
        ],
        typing.Annotated[
            types.InputMessagesFilterMusic,
            pydantic.Tag('InputMessagesFilterMusic')
        ],
        typing.Annotated[
            types.InputMessagesFilterMyMentions,
            pydantic.Tag('InputMessagesFilterMyMentions')
        ],
        typing.Annotated[
            types.InputMessagesFilterPhoneCalls,
            pydantic.Tag('InputMessagesFilterPhoneCalls')
        ],
        typing.Annotated[
            types.InputMessagesFilterPhotoVideo,
            pydantic.Tag('InputMessagesFilterPhotoVideo')
        ],
        typing.Annotated[
            types.InputMessagesFilterPhotos,
            pydantic.Tag('InputMessagesFilterPhotos')
        ],
        typing.Annotated[
            types.InputMessagesFilterPinned,
            pydantic.Tag('InputMessagesFilterPinned')
        ],
        typing.Annotated[
            types.InputMessagesFilterRoundVideo,
            pydantic.Tag('InputMessagesFilterRoundVideo')
        ],
        typing.Annotated[
            types.InputMessagesFilterRoundVoice,
            pydantic.Tag('InputMessagesFilterRoundVoice')
        ],
        typing.Annotated[
            types.InputMessagesFilterUrl,
            pydantic.Tag('InputMessagesFilterUrl')
        ],
        typing.Annotated[
            types.InputMessagesFilterVideo,
            pydantic.Tag('InputMessagesFilterVideo')
        ],
        typing.Annotated[
            types.InputMessagesFilterVoice,
            pydantic.Tag('InputMessagesFilterVoice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventsFilter(BaseModel):
    """
    types.ChannelAdminLogEventsFilter
    ID: 0xea107ae4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventsFilter', 'ChannelAdminLogEventsFilter'] = pydantic.Field(
        'types.ChannelAdminLogEventsFilter',
        alias='_'
    )

    join: typing.Optional[bool] = None
    leave: typing.Optional[bool] = None
    invite: typing.Optional[bool] = None
    ban: typing.Optional[bool] = None
    unban: typing.Optional[bool] = None
    kick: typing.Optional[bool] = None
    unkick: typing.Optional[bool] = None
    promote: typing.Optional[bool] = None
    demote: typing.Optional[bool] = None
    info: typing.Optional[bool] = None
    settings: typing.Optional[bool] = None
    pinned: typing.Optional[bool] = None
    edit: typing.Optional[bool] = None
    delete: typing.Optional[bool] = None
    group_call: typing.Optional[bool] = None
    invites: typing.Optional[bool] = None
    send: typing.Optional[bool] = None
    forums: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CreateGroupCall(BaseModel):
    """
    functions.phone.CreateGroupCall
    ID: 0x48cdc6d8
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.CreateGroupCall', 'CreateGroupCall'] = pydantic.Field(
        'functions.phone.CreateGroupCall',
        alias='_'
    )

    peer: "base.InputPeer"
    random_id: int
    rtmp_stream: typing.Optional[bool] = None
    title: typing.Optional[str] = None
    schedule_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageEntity - Layer 181
MessageEntity = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputMessageEntityMentionName,
            pydantic.Tag('InputMessageEntityMentionName')
        ],
        typing.Annotated[
            types.MessageEntityBankCard,
            pydantic.Tag('MessageEntityBankCard')
        ],
        typing.Annotated[
            types.MessageEntityBlockquote,
            pydantic.Tag('MessageEntityBlockquote')
        ],
        typing.Annotated[
            types.MessageEntityBold,
            pydantic.Tag('MessageEntityBold')
        ],
        typing.Annotated[
            types.MessageEntityBotCommand,
            pydantic.Tag('MessageEntityBotCommand')
        ],
        typing.Annotated[
            types.MessageEntityCashtag,
            pydantic.Tag('MessageEntityCashtag')
        ],
        typing.Annotated[
            types.MessageEntityCode,
            pydantic.Tag('MessageEntityCode')
        ],
        typing.Annotated[
            types.MessageEntityCustomEmoji,
            pydantic.Tag('MessageEntityCustomEmoji')
        ],
        typing.Annotated[
            types.MessageEntityEmail,
            pydantic.Tag('MessageEntityEmail')
        ],
        typing.Annotated[
            types.MessageEntityHashtag,
            pydantic.Tag('MessageEntityHashtag')
        ],
        typing.Annotated[
            types.MessageEntityItalic,
            pydantic.Tag('MessageEntityItalic')
        ],
        typing.Annotated[
            types.MessageEntityMention,
            pydantic.Tag('MessageEntityMention')
        ],
        typing.Annotated[
            types.MessageEntityMentionName,
            pydantic.Tag('MessageEntityMentionName')
        ],
        typing.Annotated[
            types.MessageEntityPhone,
            pydantic.Tag('MessageEntityPhone')
        ],
        typing.Annotated[
            types.MessageEntityPre,
            pydantic.Tag('MessageEntityPre')
        ],
        typing.Annotated[
            types.MessageEntitySpoiler,
            pydantic.Tag('MessageEntitySpoiler')
        ],
        typing.Annotated[
            types.MessageEntityStrike,
            pydantic.Tag('MessageEntityStrike')
        ],
        typing.Annotated[
            types.MessageEntityTextUrl,
            pydantic.Tag('MessageEntityTextUrl')
        ],
        typing.Annotated[
            types.MessageEntityUnderline,
            pydantic.Tag('MessageEntityUnderline')
        ],
        typing.Annotated[
            types.MessageEntityUnknown,
            pydantic.Tag('MessageEntityUnknown')
        ],
        typing.Annotated[
            types.MessageEntityUrl,
            pydantic.Tag('MessageEntityUrl')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelParticipant - Layer 181
ChannelParticipant = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChannelParticipant,
            pydantic.Tag('ChannelParticipant')
        ],
        typing.Annotated[
            types.ChannelParticipantAdmin,
            pydantic.Tag('ChannelParticipantAdmin')
        ],
        typing.Annotated[
            types.ChannelParticipantBanned,
            pydantic.Tag('ChannelParticipantBanned')
        ],
        typing.Annotated[
            types.ChannelParticipantCreator,
            pydantic.Tag('ChannelParticipantCreator')
        ],
        typing.Annotated[
            types.ChannelParticipantLeft,
            pydantic.Tag('ChannelParticipantLeft')
        ],
        typing.Annotated[
            types.ChannelParticipantSelf,
            pydantic.Tag('ChannelParticipantSelf')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateStickerSets(BaseModel):
    """
    types.UpdateStickerSets
    ID: 0x31c24808
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateStickerSets', 'UpdateStickerSets'] = pydantic.Field(
        'types.UpdateStickerSets',
        alias='_'
    )

    masks: typing.Optional[bool] = None
    emojis: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StoryReaction - Layer 181
StoryReaction = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.StoryReaction,
            pydantic.Tag('StoryReaction')
        ],
        typing.Annotated[
            types.StoryReactionPublicForward,
            pydantic.Tag('StoryReactionPublicForward')
        ],
        typing.Annotated[
            types.StoryReactionPublicRepost,
            pydantic.Tag('StoryReactionPublicRepost')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.AllStickers - Layer 181
AllStickers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.AllStickers,
            pydantic.Tag('messages.AllStickers'),
            pydantic.Tag('AllStickers')
        ],
        typing.Annotated[
            types.messages.AllStickersNotModified,
            pydantic.Tag('messages.AllStickersNotModified'),
            pydantic.Tag('AllStickersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.PeerColors - Layer 181
PeerColors = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.PeerColors,
            pydantic.Tag('help.PeerColors'),
            pydantic.Tag('PeerColors')
        ],
        typing.Annotated[
            types.help.PeerColorsNotModified,
            pydantic.Tag('help.PeerColorsNotModified'),
            pydantic.Tag('PeerColorsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputStorePaymentPremiumSubscription(BaseModel):
    """
    types.InputStorePaymentPremiumSubscription
    ID: 0xa6751e66
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputStorePaymentPremiumSubscription', 'InputStorePaymentPremiumSubscription'] = pydantic.Field(
        'types.InputStorePaymentPremiumSubscription',
        alias='_'
    )

    restore: typing.Optional[bool] = None
    upgrade: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetStickers(BaseModel):
    """
    functions.messages.GetStickers
    ID: 0xd5a5d3a1
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetStickers', 'GetStickers'] = pydantic.Field(
        'functions.messages.GetStickers',
        alias='_'
    )

    emoticon: str
    hash: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Folder(BaseModel):
    """
    types.Folder
    ID: 0xff544e65
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Folder', 'Folder'] = pydantic.Field(
        'types.Folder',
        alias='_'
    )

    id: int
    title: str
    autofill_new_broadcasts: typing.Optional[bool] = None
    autofill_public_groups: typing.Optional[bool] = None
    autofill_new_correspondents: typing.Optional[bool] = None
    photo: typing.Optional["base.ChatPhoto"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class FolderPeer(BaseModel):
    """
    types.FolderPeer
    ID: 0xe9baa668
    Layer: 181
    """
    QUALNAME: typing.Literal['types.FolderPeer', 'FolderPeer'] = pydantic.Field(
        'types.FolderPeer',
        alias='_'
    )

    peer: "base.Peer"
    folder_id: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Theme(BaseModel):
    """
    types.Theme
    ID: 0xa00e67d6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Theme', 'Theme'] = pydantic.Field(
        'types.Theme',
        alias='_'
    )

    id: int
    access_hash: int
    slug: str
    title: str
    creator: typing.Optional[bool] = None
    default: typing.Optional[bool] = None
    for_chat: typing.Optional[bool] = None
    document: typing.Optional["base.Document"] = None
    settings: typing.Optional[list["base.ThemeSettings"]] = None
    emoticon: typing.Optional[str] = None
    installs_count: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# contacts.TopPeers - Layer 181
TopPeers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.contacts.TopPeers,
            pydantic.Tag('contacts.TopPeers'),
            pydantic.Tag('TopPeers')
        ],
        typing.Annotated[
            types.contacts.TopPeersDisabled,
            pydantic.Tag('contacts.TopPeersDisabled'),
            pydantic.Tag('TopPeersDisabled')
        ],
        typing.Annotated[
            types.contacts.TopPeersNotModified,
            pydantic.Tag('contacts.TopPeersNotModified'),
            pydantic.Tag('TopPeersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatInvite - Layer 181
ChatInvite = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChatInvite,
            pydantic.Tag('ChatInvite')
        ],
        typing.Annotated[
            types.ChatInviteAlready,
            pydantic.Tag('ChatInviteAlready')
        ],
        typing.Annotated[
            types.ChatInvitePeek,
            pydantic.Tag('ChatInvitePeek')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WebDocument - Layer 181
WebDocument = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.WebDocument,
            pydantic.Tag('WebDocument')
        ],
        typing.Annotated[
            types.WebDocumentNoProxy,
            pydantic.Tag('WebDocumentNoProxy')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CollectibleInfo(BaseModel):
    """
    types.fragment.CollectibleInfo
    ID: 0x6ebdff91
    Layer: 181
    """
    QUALNAME: typing.Literal['types.fragment.CollectibleInfo', 'CollectibleInfo'] = pydantic.Field(
        'types.fragment.CollectibleInfo',
        alias='_'
    )

    purchase_date: Datetime
    currency: str
    amount: int
    crypto_currency: str
    crypto_amount: int
    url: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.GiveawayInfo - Layer 181
GiveawayInfo = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.payments.GiveawayInfo,
            pydantic.Tag('payments.GiveawayInfo'),
            pydantic.Tag('GiveawayInfo')
        ],
        typing.Annotated[
            types.payments.GiveawayInfoResults,
            pydantic.Tag('payments.GiveawayInfoResults'),
            pydantic.Tag('GiveawayInfoResults')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.AvailableReactions - Layer 181
AvailableReactions = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.AvailableReactions,
            pydantic.Tag('messages.AvailableReactions'),
            pydantic.Tag('AvailableReactions')
        ],
        typing.Annotated[
            types.messages.AvailableReactionsNotModified,
            pydantic.Tag('messages.AvailableReactionsNotModified'),
            pydantic.Tag('AvailableReactionsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputFileLocation - Layer 181
InputFileLocation = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputDocumentFileLocation,
            pydantic.Tag('InputDocumentFileLocation')
        ],
        typing.Annotated[
            types.InputEncryptedFileLocation,
            pydantic.Tag('InputEncryptedFileLocation')
        ],
        typing.Annotated[
            types.InputFileLocation,
            pydantic.Tag('InputFileLocation')
        ],
        typing.Annotated[
            types.InputGroupCallStream,
            pydantic.Tag('InputGroupCallStream')
        ],
        typing.Annotated[
            types.InputPeerPhotoFileLocation,
            pydantic.Tag('InputPeerPhotoFileLocation')
        ],
        typing.Annotated[
            types.InputPhotoFileLocation,
            pydantic.Tag('InputPhotoFileLocation')
        ],
        typing.Annotated[
            types.InputPhotoLegacyFileLocation,
            pydantic.Tag('InputPhotoLegacyFileLocation')
        ],
        typing.Annotated[
            types.InputSecureFileLocation,
            pydantic.Tag('InputSecureFileLocation')
        ],
        typing.Annotated[
            types.InputStickerSetThumb,
            pydantic.Tag('InputStickerSetThumb')
        ],
        typing.Annotated[
            types.InputTakeoutFileLocation,
            pydantic.Tag('InputTakeoutFileLocation')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Photo(BaseModel):
    """
    types.Photo
    ID: 0xfb197a65
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Photo', 'Photo'] = pydantic.Field(
        'types.Photo',
        alias='_'
    )

    id: int
    access_hash: int
    file_reference: Bytes
    date: Datetime
    sizes: list["base.PhotoSize"]
    dc_id: int
    has_stickers: typing.Optional[bool] = None
    video_sizes: typing.Optional[list["base.VideoSize"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.EmojiGroups - Layer 181
EmojiGroups = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.EmojiGroups,
            pydantic.Tag('messages.EmojiGroups'),
            pydantic.Tag('EmojiGroups')
        ],
        typing.Annotated[
            types.messages.EmojiGroupsNotModified,
            pydantic.Tag('messages.EmojiGroupsNotModified'),
            pydantic.Tag('EmojiGroupsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EncryptedChat - Layer 181
EncryptedChat = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.EncryptedChat,
            pydantic.Tag('EncryptedChat')
        ],
        typing.Annotated[
            types.EncryptedChatDiscarded,
            pydantic.Tag('EncryptedChatDiscarded')
        ],
        typing.Annotated[
            types.EncryptedChatEmpty,
            pydantic.Tag('EncryptedChatEmpty')
        ],
        typing.Annotated[
            types.EncryptedChatRequested,
            pydantic.Tag('EncryptedChatRequested')
        ],
        typing.Annotated[
            types.EncryptedChatWaiting,
            pydantic.Tag('EncryptedChatWaiting')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CountryCode(BaseModel):
    """
    types.help.CountryCode
    ID: 0x4203c5ef
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.CountryCode', 'CountryCode'] = pydantic.Field(
        'types.help.CountryCode',
        alias='_'
    )

    country_code: str
    prefixes: typing.Optional[list[str]] = None
    patterns: typing.Optional[list[str]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageEntityPre(BaseModel):
    """
    types.MessageEntityPre
    ID: 0x73924be0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageEntityPre', 'MessageEntityPre'] = pydantic.Field(
        'types.MessageEntityPre',
        alias='_'
    )

    offset: int
    length: int
    language: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# account.PasswordInputSettings - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
PasswordInputSettings = typing.Union[
    typing.Annotated[
        types.account.PasswordInputSettings,
        pydantic.Tag('account.PasswordInputSettings'),
        pydantic.Tag('PasswordInputSettings')
    ]
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionExportedInviteEdit(BaseModel):
    """
    types.ChannelAdminLogEventActionExportedInviteEdit
    ID: 0xe90ebb59
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionExportedInviteEdit', 'ChannelAdminLogEventActionExportedInviteEdit'] = pydantic.Field(
        'types.ChannelAdminLogEventActionExportedInviteEdit',
        alias='_'
    )

    prev_invite: "base.ExportedChatInvite"
    new_invite: "base.ExportedChatInvite"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BusinessAwayMessageSchedule - Layer 181
BusinessAwayMessageSchedule = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BusinessAwayMessageScheduleAlways,
            pydantic.Tag('BusinessAwayMessageScheduleAlways')
        ],
        typing.Annotated[
            types.BusinessAwayMessageScheduleCustom,
            pydantic.Tag('BusinessAwayMessageScheduleCustom')
        ],
        typing.Annotated[
            types.BusinessAwayMessageScheduleOutsideWorkHours,
            pydantic.Tag('BusinessAwayMessageScheduleOutsideWorkHours')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.AvailableEffects - Layer 181
AvailableEffects = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.AvailableEffects,
            pydantic.Tag('messages.AvailableEffects'),
            pydantic.Tag('AvailableEffects')
        ],
        typing.Annotated[
            types.messages.AvailableEffectsNotModified,
            pydantic.Tag('messages.AvailableEffectsNotModified'),
            pydantic.Tag('AvailableEffectsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneCallWaiting(BaseModel):
    """
    types.PhoneCallWaiting
    ID: 0xc5226f17
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneCallWaiting', 'PhoneCallWaiting'] = pydantic.Field(
        'types.PhoneCallWaiting',
        alias='_'
    )

    id: int
    access_hash: int
    date: Datetime
    admin_id: int
    participant_id: int
    protocol: "base.PhoneCallProtocol"
    video: typing.Optional[bool] = None
    receive_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DocumentAttributeVideo(BaseModel):
    """
    types.DocumentAttributeVideo
    ID: 0xd38ff1c2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DocumentAttributeVideo', 'DocumentAttributeVideo'] = pydantic.Field(
        'types.DocumentAttributeVideo',
        alias='_'
    )

    duration: float
    w: int
    h: int
    round_message: typing.Optional[bool] = None
    supports_streaming: typing.Optional[bool] = None
    nosound: typing.Optional[bool] = None
    preload_prefix_size: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.TermsOfServiceUpdate - Layer 181
TermsOfServiceUpdate = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.TermsOfServiceUpdate,
            pydantic.Tag('help.TermsOfServiceUpdate'),
            pydantic.Tag('TermsOfServiceUpdate')
        ],
        typing.Annotated[
            types.help.TermsOfServiceUpdateEmpty,
            pydantic.Tag('help.TermsOfServiceUpdateEmpty'),
            pydantic.Tag('TermsOfServiceUpdateEmpty')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateMessageReactions(BaseModel):
    """
    types.UpdateMessageReactions
    ID: 0x5e1b3cb8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateMessageReactions', 'UpdateMessageReactions'] = pydantic.Field(
        'types.UpdateMessageReactions',
        alias='_'
    )

    peer: "base.Peer"
    msg_id: int
    reactions: "base.MessageReactions"
    top_msg_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputStorePaymentPurpose - Layer 181
InputStorePaymentPurpose = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputStorePaymentGiftPremium,
            pydantic.Tag('InputStorePaymentGiftPremium')
        ],
        typing.Annotated[
            types.InputStorePaymentPremiumGiftCode,
            pydantic.Tag('InputStorePaymentPremiumGiftCode')
        ],
        typing.Annotated[
            types.InputStorePaymentPremiumGiveaway,
            pydantic.Tag('InputStorePaymentPremiumGiveaway')
        ],
        typing.Annotated[
            types.InputStorePaymentPremiumSubscription,
            pydantic.Tag('InputStorePaymentPremiumSubscription')
        ],
        typing.Annotated[
            types.InputStorePaymentStars,
            pydantic.Tag('InputStorePaymentStars')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.SentCodeType - Layer 181
SentCodeType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.auth.SentCodeTypeApp,
            pydantic.Tag('auth.SentCodeTypeApp'),
            pydantic.Tag('SentCodeTypeApp')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeCall,
            pydantic.Tag('auth.SentCodeTypeCall'),
            pydantic.Tag('SentCodeTypeCall')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeEmailCode,
            pydantic.Tag('auth.SentCodeTypeEmailCode'),
            pydantic.Tag('SentCodeTypeEmailCode')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeFirebaseSms,
            pydantic.Tag('auth.SentCodeTypeFirebaseSms'),
            pydantic.Tag('SentCodeTypeFirebaseSms')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeFlashCall,
            pydantic.Tag('auth.SentCodeTypeFlashCall'),
            pydantic.Tag('SentCodeTypeFlashCall')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeFragmentSms,
            pydantic.Tag('auth.SentCodeTypeFragmentSms'),
            pydantic.Tag('SentCodeTypeFragmentSms')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeMissedCall,
            pydantic.Tag('auth.SentCodeTypeMissedCall'),
            pydantic.Tag('SentCodeTypeMissedCall')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeSetUpEmailRequired,
            pydantic.Tag('auth.SentCodeTypeSetUpEmailRequired'),
            pydantic.Tag('SentCodeTypeSetUpEmailRequired')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeSms,
            pydantic.Tag('auth.SentCodeTypeSms'),
            pydantic.Tag('SentCodeTypeSms')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeSmsPhrase,
            pydantic.Tag('auth.SentCodeTypeSmsPhrase'),
            pydantic.Tag('SentCodeTypeSmsPhrase')
        ],
        typing.Annotated[
            types.auth.SentCodeTypeSmsWord,
            pydantic.Tag('auth.SentCodeTypeSmsWord'),
            pydantic.Tag('SentCodeTypeSmsWord')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# updates.Difference - Layer 181
Difference = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.updates.Difference,
            pydantic.Tag('updates.Difference'),
            pydantic.Tag('Difference')
        ],
        typing.Annotated[
            types.updates.DifferenceEmpty,
            pydantic.Tag('updates.DifferenceEmpty'),
            pydantic.Tag('DifferenceEmpty')
        ],
        typing.Annotated[
            types.updates.DifferenceSlice,
            pydantic.Tag('updates.DifferenceSlice'),
            pydantic.Tag('DifferenceSlice')
        ],
        typing.Annotated[
            types.updates.DifferenceTooLong,
            pydantic.Tag('updates.DifferenceTooLong'),
            pydantic.Tag('DifferenceTooLong')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Reactions(BaseModel):
    """
    types.messages.Reactions
    ID: 0xeafdf716
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.Reactions', 'Reactions'] = pydantic.Field(
        'types.messages.Reactions',
        alias='_'
    )

    hash: int
    reactions: list["base.Reaction"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.Authorization - Layer 181
Authorization = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.auth.Authorization,
            pydantic.Tag('auth.Authorization'),
            pydantic.Tag('Authorization')
        ],
        typing.Annotated[
            types.auth.AuthorizationSignUpRequired,
            pydantic.Tag('auth.AuthorizationSignUpRequired'),
            pydantic.Tag('AuthorizationSignUpRequired')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportedMessageLink(BaseModel):
    """
    types.ExportedMessageLink
    ID: 0x5dab1af4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ExportedMessageLink', 'ExportedMessageLink'] = pydantic.Field(
        'types.ExportedMessageLink',
        alias='_'
    )

    link: str
    html: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StickerSet(BaseModel):
    """
    types.StickerSet
    ID: 0x2dd14edc
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StickerSet', 'StickerSet'] = pydantic.Field(
        'types.StickerSet',
        alias='_'
    )

    id: int
    access_hash: int
    title: str
    short_name: str
    count: int
    hash: int
    archived: typing.Optional[bool] = None
    official: typing.Optional[bool] = None
    masks: typing.Optional[bool] = None
    emojis: typing.Optional[bool] = None
    text_color: typing.Optional[bool] = None
    channel_emoji_status: typing.Optional[bool] = None
    creator: typing.Optional[bool] = None
    installed_date: typing.Optional[Datetime] = None
    thumbs: typing.Optional[list["base.PhotoSize"]] = None
    thumb_dc_id: typing.Optional[int] = None
    thumb_version: typing.Optional[int] = None
    thumb_document_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateStoryID(BaseModel):
    """
    types.UpdateStoryID
    ID: 0x1bf335b9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateStoryID', 'UpdateStoryID'] = pydantic.Field(
        'types.UpdateStoryID',
        alias='_'
    )

    id: int
    random_id: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockMap(BaseModel):
    """
    types.PageBlockMap
    ID: 0xa44f3ef6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockMap', 'PageBlockMap'] = pydantic.Field(
        'types.PageBlockMap',
        alias='_'
    )

    geo: "base.GeoPoint"
    zoom: int
    w: int
    h: int
    caption: "base.PageCaption"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentCodeTypeEmailCode(BaseModel):
    """
    types.auth.SentCodeTypeEmailCode
    ID: 0xf450f59b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.SentCodeTypeEmailCode', 'SentCodeTypeEmailCode'] = pydantic.Field(
        'types.auth.SentCodeTypeEmailCode',
        alias='_'
    )

    email_pattern: str
    length: int
    apple_signin_allowed: typing.Optional[bool] = None
    google_signin_allowed: typing.Optional[bool] = None
    reset_available_period: typing.Optional[int] = None
    reset_pending_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentResult - Layer 181
PaymentResult = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.payments.PaymentResult,
            pydantic.Tag('payments.PaymentResult'),
            pydantic.Tag('PaymentResult')
        ],
        typing.Annotated[
            types.payments.PaymentVerificationNeeded,
            pydantic.Tag('payments.PaymentVerificationNeeded'),
            pydantic.Tag('PaymentVerificationNeeded')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# JSONValue - Layer 181
JSONValue = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.JsonArray,
            pydantic.Tag('JsonArray')
        ],
        typing.Annotated[
            types.JsonBool,
            pydantic.Tag('JsonBool')
        ],
        typing.Annotated[
            types.JsonNull,
            pydantic.Tag('JsonNull')
        ],
        typing.Annotated[
            types.JsonNumber,
            pydantic.Tag('JsonNumber')
        ],
        typing.Annotated[
            types.JsonObject,
            pydantic.Tag('JsonObject')
        ],
        typing.Annotated[
            types.JsonString,
            pydantic.Tag('JsonString')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestPeerTypeUser(BaseModel):
    """
    types.RequestPeerTypeUser
    ID: 0x5f3b8a00
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RequestPeerTypeUser', 'RequestPeerTypeUser'] = pydantic.Field(
        'types.RequestPeerTypeUser',
        alias='_'
    )

    bot: typing.Optional[bool] = None
    premium: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelDifferenceTooLong(BaseModel):
    """
    types.updates.ChannelDifferenceTooLong
    ID: 0xa4bcc6fe
    Layer: 181
    """
    QUALNAME: typing.Literal['types.updates.ChannelDifferenceTooLong', 'ChannelDifferenceTooLong'] = pydantic.Field(
        'types.updates.ChannelDifferenceTooLong',
        alias='_'
    )

    dialog: "base.Dialog"
    messages: list["base.Message"]
    chats: list["base.Chat"]
    users: list["base.User"]
    final: typing.Optional[bool] = None
    timeout: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionSetChatWallPaper(BaseModel):
    """
    types.MessageActionSetChatWallPaper
    ID: 0x5060a3f4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionSetChatWallPaper', 'MessageActionSetChatWallPaper'] = pydantic.Field(
        'types.MessageActionSetChatWallPaper',
        alias='_'
    )

    wallpaper: "base.WallPaper"
    same: typing.Optional[bool] = None
    for_both: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# AttachMenuPeerType - Layer 181
AttachMenuPeerType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.AttachMenuPeerTypeBotPM,
            pydantic.Tag('AttachMenuPeerTypeBotPM')
        ],
        typing.Annotated[
            types.AttachMenuPeerTypeBroadcast,
            pydantic.Tag('AttachMenuPeerTypeBroadcast')
        ],
        typing.Annotated[
            types.AttachMenuPeerTypeChat,
            pydantic.Tag('AttachMenuPeerTypeChat')
        ],
        typing.Annotated[
            types.AttachMenuPeerTypePM,
            pydantic.Tag('AttachMenuPeerTypePM')
        ],
        typing.Annotated[
            types.AttachMenuPeerTypeSameBotPM,
            pydantic.Tag('AttachMenuPeerTypeSameBotPM')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateNewAuthorization(BaseModel):
    """
    types.UpdateNewAuthorization
    ID: 0x8951abef
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateNewAuthorization', 'UpdateNewAuthorization'] = pydantic.Field(
        'types.UpdateNewAuthorization',
        alias='_'
    )

    hash: int
    unconfirmed: typing.Optional[bool] = None
    date: typing.Optional[Datetime] = None
    device: typing.Optional[str] = None
    location: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PostAddress(BaseModel):
    """
    types.PostAddress
    ID: 0x1e8caaeb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PostAddress', 'PostAddress'] = pydantic.Field(
        'types.PostAddress',
        alias='_'
    )

    street_line1: str
    street_line2: str
    city: str
    state: str
    country_iso2: str
    post_code: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.EmailVerified - Layer 181
EmailVerified = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.EmailVerified,
            pydantic.Tag('account.EmailVerified'),
            pydantic.Tag('EmailVerified')
        ],
        typing.Annotated[
            types.account.EmailVerifiedLogin,
            pydantic.Tag('account.EmailVerifiedLogin'),
            pydantic.Tag('EmailVerifiedLogin')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetFactCheck(BaseModel):
    """
    functions.messages.GetFactCheck
    ID: 0xb9cdc5ee
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetFactCheck', 'GetFactCheck'] = pydantic.Field(
        'functions.messages.GetFactCheck',
        alias='_'
    )

    peer: "base.InputPeer"
    msg_id: list[int]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GiveawayInfo(BaseModel):
    """
    types.payments.GiveawayInfo
    ID: 0x4367daa0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.GiveawayInfo', 'GiveawayInfo'] = pydantic.Field(
        'types.payments.GiveawayInfo',
        alias='_'
    )

    start_date: Datetime
    participating: typing.Optional[bool] = None
    preparing_results: typing.Optional[bool] = None
    joined_too_early_date: typing.Optional[Datetime] = None
    admin_disallowed_chat_id: typing.Optional[int] = None
    disallowed_country: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotMessageReactions(BaseModel):
    """
    types.UpdateBotMessageReactions
    ID: 0x9cb7759
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotMessageReactions', 'UpdateBotMessageReactions'] = pydantic.Field(
        'types.UpdateBotMessageReactions',
        alias='_'
    )

    peer: "base.Peer"
    msg_id: int
    date: Datetime
    reactions: list["base.ReactionCount"]
    qts: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PageBlock - Layer 181
PageBlock = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PageBlockAnchor,
            pydantic.Tag('PageBlockAnchor')
        ],
        typing.Annotated[
            types.PageBlockAudio,
            pydantic.Tag('PageBlockAudio')
        ],
        typing.Annotated[
            types.PageBlockAuthorDate,
            pydantic.Tag('PageBlockAuthorDate')
        ],
        typing.Annotated[
            types.PageBlockBlockquote,
            pydantic.Tag('PageBlockBlockquote')
        ],
        typing.Annotated[
            types.PageBlockChannel,
            pydantic.Tag('PageBlockChannel')
        ],
        typing.Annotated[
            types.PageBlockCollage,
            pydantic.Tag('PageBlockCollage')
        ],
        typing.Annotated[
            types.PageBlockCover,
            pydantic.Tag('PageBlockCover')
        ],
        typing.Annotated[
            types.PageBlockDetails,
            pydantic.Tag('PageBlockDetails')
        ],
        typing.Annotated[
            types.PageBlockDivider,
            pydantic.Tag('PageBlockDivider')
        ],
        typing.Annotated[
            types.PageBlockEmbed,
            pydantic.Tag('PageBlockEmbed')
        ],
        typing.Annotated[
            types.PageBlockEmbedPost,
            pydantic.Tag('PageBlockEmbedPost')
        ],
        typing.Annotated[
            types.PageBlockFooter,
            pydantic.Tag('PageBlockFooter')
        ],
        typing.Annotated[
            types.PageBlockHeader,
            pydantic.Tag('PageBlockHeader')
        ],
        typing.Annotated[
            types.PageBlockKicker,
            pydantic.Tag('PageBlockKicker')
        ],
        typing.Annotated[
            types.PageBlockList,
            pydantic.Tag('PageBlockList')
        ],
        typing.Annotated[
            types.PageBlockMap,
            pydantic.Tag('PageBlockMap')
        ],
        typing.Annotated[
            types.PageBlockOrderedList,
            pydantic.Tag('PageBlockOrderedList')
        ],
        typing.Annotated[
            types.PageBlockParagraph,
            pydantic.Tag('PageBlockParagraph')
        ],
        typing.Annotated[
            types.PageBlockPhoto,
            pydantic.Tag('PageBlockPhoto')
        ],
        typing.Annotated[
            types.PageBlockPreformatted,
            pydantic.Tag('PageBlockPreformatted')
        ],
        typing.Annotated[
            types.PageBlockPullquote,
            pydantic.Tag('PageBlockPullquote')
        ],
        typing.Annotated[
            types.PageBlockRelatedArticles,
            pydantic.Tag('PageBlockRelatedArticles')
        ],
        typing.Annotated[
            types.PageBlockSlideshow,
            pydantic.Tag('PageBlockSlideshow')
        ],
        typing.Annotated[
            types.PageBlockSubheader,
            pydantic.Tag('PageBlockSubheader')
        ],
        typing.Annotated[
            types.PageBlockSubtitle,
            pydantic.Tag('PageBlockSubtitle')
        ],
        typing.Annotated[
            types.PageBlockTable,
            pydantic.Tag('PageBlockTable')
        ],
        typing.Annotated[
            types.PageBlockTitle,
            pydantic.Tag('PageBlockTitle')
        ],
        typing.Annotated[
            types.PageBlockUnsupported,
            pydantic.Tag('PageBlockUnsupported')
        ],
        typing.Annotated[
            types.PageBlockVideo,
            pydantic.Tag('PageBlockVideo')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.RecentStickers - Layer 181
RecentStickers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.RecentStickers,
            pydantic.Tag('messages.RecentStickers'),
            pydantic.Tag('RecentStickers')
        ],
        typing.Annotated[
            types.messages.RecentStickersNotModified,
            pydantic.Tag('messages.RecentStickersNotModified'),
            pydantic.Tag('RecentStickersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# account.ContentSettings - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
ContentSettings = typing.Union[
    typing.Annotated[
        types.account.ContentSettings,
        pydantic.Tag('account.ContentSettings'),
        pydantic.Tag('ContentSettings')
    ]
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageEntityBold(BaseModel):
    """
    types.MessageEntityBold
    ID: 0xbd610bc9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageEntityBold', 'MessageEntityBold'] = pydantic.Field(
        'types.MessageEntityBold',
        alias='_'
    )

    offset: int
    length: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Dialog(BaseModel):
    """
    types.Dialog
    ID: 0xd58a08c6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Dialog', 'Dialog'] = pydantic.Field(
        'types.Dialog',
        alias='_'
    )

    peer: "base.Peer"
    top_message: int
    read_inbox_max_id: int
    read_outbox_max_id: int
    unread_count: int
    unread_mentions_count: int
    unread_reactions_count: int
    notify_settings: "base.PeerNotifySettings"
    pinned: typing.Optional[bool] = None
    unread_mark: typing.Optional[bool] = None
    view_forum_as_messages: typing.Optional[bool] = None
    pts: typing.Optional[int] = None
    draft: typing.Optional["base.DraftMessage"] = None
    folder_id: typing.Optional[int] = None
    ttl_period: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecurePasswordKdfAlgo - Layer 181
SecurePasswordKdfAlgo = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000,
            pydantic.Tag('SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000')
        ],
        typing.Annotated[
            types.SecurePasswordKdfAlgoSHA512,
            pydantic.Tag('SecurePasswordKdfAlgoSHA512')
        ],
        typing.Annotated[
            types.SecurePasswordKdfAlgoUnknown,
            pydantic.Tag('SecurePasswordKdfAlgoUnknown')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestSimpleWebView(BaseModel):
    """
    functions.messages.RequestSimpleWebView
    ID: 0x1a46500a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.RequestSimpleWebView', 'RequestSimpleWebView'] = pydantic.Field(
        'functions.messages.RequestSimpleWebView',
        alias='_'
    )

    bot: "base.InputUser"
    platform: str
    from_switch_webview: typing.Optional[bool] = None
    from_side_menu: typing.Optional[bool] = None
    url: typing.Optional[str] = None
    start_param: typing.Optional[str] = None
    theme_params: typing.Optional["base.DataJSON"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditForumTopic(BaseModel):
    """
    functions.channels.EditForumTopic
    ID: 0xf4dfa185
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.EditForumTopic', 'EditForumTopic'] = pydantic.Field(
        'functions.channels.EditForumTopic',
        alias='_'
    )

    channel: "base.InputChannel"
    topic_id: int
    title: typing.Optional[str] = None
    icon_emoji_id: typing.Optional[int] = None
    closed: typing.Optional[bool] = None
    hidden: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotMessageReaction(BaseModel):
    """
    types.UpdateBotMessageReaction
    ID: 0xac21d3ce
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotMessageReaction', 'UpdateBotMessageReaction'] = pydantic.Field(
        'types.UpdateBotMessageReaction',
        alias='_'
    )

    peer: "base.Peer"
    msg_id: int
    date: Datetime
    actor: "base.Peer"
    old_reactions: list["base.Reaction"]
    new_reactions: list["base.Reaction"]
    qts: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PostInteractionCountersMessage(BaseModel):
    """
    types.PostInteractionCountersMessage
    ID: 0xe7058e7f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PostInteractionCountersMessage', 'PostInteractionCountersMessage'] = pydantic.Field(
        'types.PostInteractionCountersMessage',
        alias='_'
    )

    msg_id: int
    views: int
    forwards: int
    reactions: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AddContact(BaseModel):
    """
    functions.contacts.AddContact
    ID: 0xe8f463d0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.AddContact', 'AddContact'] = pydantic.Field(
        'functions.contacts.AddContact',
        alias='_'
    )

    id: "base.InputUser"
    first_name: str
    last_name: str
    phone: str
    add_phone_privacy_exception: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryViewsList(BaseModel):
    """
    types.stories.StoryViewsList
    ID: 0x59d78fc5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stories.StoryViewsList', 'StoryViewsList'] = pydantic.Field(
        'types.stories.StoryViewsList',
        alias='_'
    )

    count: int
    views_count: int
    forwards_count: int
    reactions_count: int
    views: list["base.StoryView"]
    chats: list["base.Chat"]
    users: list["base.User"]
    next_offset: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# chatlists.ChatlistInvite - Layer 181
ChatlistInvite = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.chatlists.ChatlistInvite,
            pydantic.Tag('chatlists.ChatlistInvite'),
            pydantic.Tag('ChatlistInvite')
        ],
        typing.Annotated[
            types.chatlists.ChatlistInviteAlready,
            pydantic.Tag('chatlists.ChatlistInviteAlready'),
            pydantic.Tag('ChatlistInviteAlready')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputFile(BaseModel):
    """
    types.InputFile
    ID: 0xf52ff27f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputFile', 'InputFile'] = pydantic.Field(
        'types.InputFile',
        alias='_'
    )

    id: int
    parts: int
    name: str
    md5_checksum: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateEmojiStatus(BaseModel):
    """
    functions.account.UpdateEmojiStatus
    ID: 0xfbd3de6b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateEmojiStatus', 'UpdateEmojiStatus'] = pydantic.Field(
        'functions.account.UpdateEmojiStatus',
        alias='_'
    )

    emoji_status: "base.EmojiStatus"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetStrings(BaseModel):
    """
    functions.langpack.GetStrings
    ID: 0xefea3803
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.langpack.GetStrings', 'GetStrings'] = pydantic.Field(
        'functions.langpack.GetStrings',
        alias='_'
    )

    lang_pack: str
    lang_code: str
    keys: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Authorizations(BaseModel):
    """
    types.account.Authorizations
    ID: 0x4bff8ea0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.Authorizations', 'Authorizations'] = pydantic.Field(
        'types.account.Authorizations',
        alias='_'
    )

    authorization_ttl_days: int
    authorizations: list["base.Authorization"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportedInvites(BaseModel):
    """
    types.chatlists.ExportedInvites
    ID: 0x10ab6dc7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.chatlists.ExportedInvites', 'ExportedInvites'] = pydantic.Field(
        'types.chatlists.ExportedInvites',
        alias='_'
    )

    invites: list["base.ExportedChatlistInvite"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CheckedGiftCode(BaseModel):
    """
    types.payments.CheckedGiftCode
    ID: 0x284a1096
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.CheckedGiftCode', 'CheckedGiftCode'] = pydantic.Field(
        'types.payments.CheckedGiftCode',
        alias='_'
    )

    date: Datetime
    months: int
    chats: list["base.Chat"]
    users: list["base.User"]
    via_giveaway: typing.Optional[bool] = None
    from_id: typing.Optional["base.Peer"] = None
    giveaway_msg_id: typing.Optional[int] = None
    to_id: typing.Optional[int] = None
    used_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendInlineBotResult(BaseModel):
    """
    functions.messages.SendInlineBotResult
    ID: 0x3ebee86a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SendInlineBotResult', 'SendInlineBotResult'] = pydantic.Field(
        'functions.messages.SendInlineBotResult',
        alias='_'
    )

    peer: "base.InputPeer"
    random_id: int
    query_id: int
    id: str
    silent: typing.Optional[bool] = None
    background: typing.Optional[bool] = None
    clear_draft: typing.Optional[bool] = None
    hide_via: typing.Optional[bool] = None
    reply_to: typing.Optional["base.InputReplyTo"] = None
    schedule_date: typing.Optional[Datetime] = None
    send_as: typing.Optional["base.InputPeer"] = None
    quick_reply_shortcut: typing.Optional["base.InputQuickReplyShortcut"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RestrictionReason(BaseModel):
    """
    types.RestrictionReason
    ID: 0xd072acb4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RestrictionReason', 'RestrictionReason'] = pydantic.Field(
        'types.RestrictionReason',
        alias='_'
    )

    platform: str
    reason: str
    text: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputDocumentFileLocation(BaseModel):
    """
    types.InputDocumentFileLocation
    ID: 0xbad07584
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputDocumentFileLocation', 'InputDocumentFileLocation'] = pydantic.Field(
        'types.InputDocumentFileLocation',
        alias='_'
    )

    id: int
    access_hash: int
    file_reference: Bytes
    thumb_size: str



__version__ = '0.181.5'

from . import base
from . import types
from . import functions

types.BoolFalse.model_rebuild()
types.BoolTrue.model_rebuild()
types.Error.model_rebuild()
types.Null.model_rebuild()
types.InputPeerEmpty.model_rebuild()
types.InputPeerSelf.model_rebuild()
types.InputPeerChat.model_rebuild()
types.InputPeerUser.model_rebuild()
types.InputPeerChannel.model_rebuild()
types.InputPeerUserFromMessage.model_rebuild()
types.InputPeerChannelFromMessage.model_rebuild()
types.InputUserEmpty.model_rebuild()
types.InputUserSelf.model_rebuild()
types.InputUser.model_rebuild()
types.InputUserFromMessage.model_rebuild()
types.InputPhoneContact.model_rebuild()
types.InputFile.model_rebuild()
types.InputFileBig.model_rebuild()
types.InputMediaEmpty.model_rebuild()
types.InputMediaUploadedPhoto.model_rebuild()
types.InputMediaPhoto.model_rebuild()
types.InputMediaGeoPoint.model_rebuild()
types.InputMediaContact.model_rebuild()
types.InputMediaUploadedDocument.model_rebuild()
types.InputMediaDocument.model_rebuild()
types.InputMediaVenue.model_rebuild()
types.InputMediaPhotoExternal.model_rebuild()
types.InputMediaDocumentExternal.model_rebuild()
types.InputMediaGame.model_rebuild()
types.InputMediaInvoice.model_rebuild()
types.InputMediaGeoLive.model_rebuild()
types.InputMediaPoll.model_rebuild()
types.InputMediaDice.model_rebuild()
types.InputMediaStory.model_rebuild()
types.InputMediaWebPage.model_rebuild()
types.InputChatPhotoEmpty.model_rebuild()
types.InputChatUploadedPhoto.model_rebuild()
types.InputChatPhoto.model_rebuild()
types.InputGeoPointEmpty.model_rebuild()
types.InputGeoPoint.model_rebuild()
types.InputPhotoEmpty.model_rebuild()
types.InputPhoto.model_rebuild()
types.InputFileLocation.model_rebuild()
types.InputEncryptedFileLocation.model_rebuild()
types.InputDocumentFileLocation.model_rebuild()
types.InputSecureFileLocation.model_rebuild()
types.InputTakeoutFileLocation.model_rebuild()
types.InputPhotoFileLocation.model_rebuild()
types.InputPhotoLegacyFileLocation.model_rebuild()
types.InputPeerPhotoFileLocation.model_rebuild()
types.InputStickerSetThumb.model_rebuild()
types.InputGroupCallStream.model_rebuild()
types.PeerUser.model_rebuild()
types.PeerChat.model_rebuild()
types.PeerChannel.model_rebuild()
types.UserEmpty.model_rebuild()
types.User.model_rebuild()
types.UserProfilePhotoEmpty.model_rebuild()
types.UserProfilePhoto.model_rebuild()
types.UserStatusEmpty.model_rebuild()
types.UserStatusOnline.model_rebuild()
types.UserStatusOffline.model_rebuild()
types.UserStatusRecently.model_rebuild()
types.UserStatusLastWeek.model_rebuild()
types.UserStatusLastMonth.model_rebuild()
types.ChatEmpty.model_rebuild()
types.Chat.model_rebuild()
types.ChatForbidden.model_rebuild()
types.Channel.model_rebuild()
types.ChannelForbidden.model_rebuild()
types.ChatFull.model_rebuild()
types.ChannelFull.model_rebuild()
types.ChatParticipant.model_rebuild()
types.ChatParticipantCreator.model_rebuild()
types.ChatParticipantAdmin.model_rebuild()
types.ChatParticipantsForbidden.model_rebuild()
types.ChatParticipants.model_rebuild()
types.ChatPhotoEmpty.model_rebuild()
types.ChatPhoto.model_rebuild()
types.MessageEmpty.model_rebuild()
types.Message.model_rebuild()
types.MessageService.model_rebuild()
types.MessageMediaEmpty.model_rebuild()
types.MessageMediaPhoto.model_rebuild()
types.MessageMediaGeo.model_rebuild()
types.MessageMediaContact.model_rebuild()
types.MessageMediaUnsupported.model_rebuild()
types.MessageMediaDocument.model_rebuild()
types.MessageMediaWebPage.model_rebuild()
types.MessageMediaVenue.model_rebuild()
types.MessageMediaGame.model_rebuild()
types.MessageMediaInvoice.model_rebuild()
types.MessageMediaGeoLive.model_rebuild()
types.MessageMediaPoll.model_rebuild()
types.MessageMediaDice.model_rebuild()
types.MessageMediaStory.model_rebuild()
types.MessageMediaGiveaway.model_rebuild()
types.MessageMediaGiveawayResults.model_rebuild()
types.MessageActionEmpty.model_rebuild()
types.MessageActionChatCreate.model_rebuild()
types.MessageActionChatEditTitle.model_rebuild()
types.MessageActionChatEditPhoto.model_rebuild()
types.MessageActionChatDeletePhoto.model_rebuild()
types.MessageActionChatAddUser.model_rebuild()
types.MessageActionChatDeleteUser.model_rebuild()
types.MessageActionChatJoinedByLink.model_rebuild()
types.MessageActionChannelCreate.model_rebuild()
types.MessageActionChatMigrateTo.model_rebuild()
types.MessageActionChannelMigrateFrom.model_rebuild()
types.MessageActionPinMessage.model_rebuild()
types.MessageActionHistoryClear.model_rebuild()
types.MessageActionGameScore.model_rebuild()
types.MessageActionPaymentSentMe.model_rebuild()
types.MessageActionPaymentSent.model_rebuild()
types.MessageActionPhoneCall.model_rebuild()
types.MessageActionScreenshotTaken.model_rebuild()
types.MessageActionCustomAction.model_rebuild()
types.MessageActionBotAllowed.model_rebuild()
types.MessageActionSecureValuesSentMe.model_rebuild()
types.MessageActionSecureValuesSent.model_rebuild()
types.MessageActionContactSignUp.model_rebuild()
types.MessageActionGeoProximityReached.model_rebuild()
types.MessageActionGroupCall.model_rebuild()
types.MessageActionInviteToGroupCall.model_rebuild()
types.MessageActionSetMessagesTTL.model_rebuild()
types.MessageActionGroupCallScheduled.model_rebuild()
types.MessageActionSetChatTheme.model_rebuild()
types.MessageActionChatJoinedByRequest.model_rebuild()
types.MessageActionWebViewDataSentMe.model_rebuild()
types.MessageActionWebViewDataSent.model_rebuild()
types.MessageActionGiftPremium.model_rebuild()
types.MessageActionTopicCreate.model_rebuild()
types.MessageActionTopicEdit.model_rebuild()
types.MessageActionSuggestProfilePhoto.model_rebuild()
types.MessageActionRequestedPeer.model_rebuild()
types.MessageActionSetChatWallPaper.model_rebuild()
types.MessageActionGiftCode.model_rebuild()
types.MessageActionGiveawayLaunch.model_rebuild()
types.MessageActionGiveawayResults.model_rebuild()
types.MessageActionBoostApply.model_rebuild()
types.MessageActionRequestedPeerSentMe.model_rebuild()
types.Dialog.model_rebuild()
types.DialogFolder.model_rebuild()
types.PhotoEmpty.model_rebuild()
types.Photo.model_rebuild()
types.PhotoSizeEmpty.model_rebuild()
types.PhotoSize.model_rebuild()
types.PhotoCachedSize.model_rebuild()
types.PhotoStrippedSize.model_rebuild()
types.PhotoSizeProgressive.model_rebuild()
types.PhotoPathSize.model_rebuild()
types.GeoPointEmpty.model_rebuild()
types.GeoPoint.model_rebuild()
types.InputNotifyPeer.model_rebuild()
types.InputNotifyUsers.model_rebuild()
types.InputNotifyChats.model_rebuild()
types.InputNotifyBroadcasts.model_rebuild()
types.InputNotifyForumTopic.model_rebuild()
types.InputPeerNotifySettings.model_rebuild()
types.PeerNotifySettings.model_rebuild()
types.PeerSettings.model_rebuild()
types.WallPaper.model_rebuild()
types.WallPaperNoFile.model_rebuild()
types.InputReportReasonSpam.model_rebuild()
types.InputReportReasonViolence.model_rebuild()
types.InputReportReasonPornography.model_rebuild()
types.InputReportReasonChildAbuse.model_rebuild()
types.InputReportReasonOther.model_rebuild()
types.InputReportReasonCopyright.model_rebuild()
types.InputReportReasonGeoIrrelevant.model_rebuild()
types.InputReportReasonFake.model_rebuild()
types.InputReportReasonIllegalDrugs.model_rebuild()
types.InputReportReasonPersonalDetails.model_rebuild()
types.UserFull.model_rebuild()
types.Contact.model_rebuild()
types.ImportedContact.model_rebuild()
types.ContactStatus.model_rebuild()
types.InputMessagesFilterEmpty.model_rebuild()
types.InputMessagesFilterPhotos.model_rebuild()
types.InputMessagesFilterVideo.model_rebuild()
types.InputMessagesFilterPhotoVideo.model_rebuild()
types.InputMessagesFilterDocument.model_rebuild()
types.InputMessagesFilterUrl.model_rebuild()
types.InputMessagesFilterGif.model_rebuild()
types.InputMessagesFilterVoice.model_rebuild()
types.InputMessagesFilterMusic.model_rebuild()
types.InputMessagesFilterChatPhotos.model_rebuild()
types.InputMessagesFilterPhoneCalls.model_rebuild()
types.InputMessagesFilterRoundVoice.model_rebuild()
types.InputMessagesFilterRoundVideo.model_rebuild()
types.InputMessagesFilterMyMentions.model_rebuild()
types.InputMessagesFilterGeo.model_rebuild()
types.InputMessagesFilterContacts.model_rebuild()
types.InputMessagesFilterPinned.model_rebuild()
types.UpdateNewMessage.model_rebuild()
types.UpdateMessageID.model_rebuild()
types.UpdateDeleteMessages.model_rebuild()
types.UpdateUserTyping.model_rebuild()
types.UpdateChatUserTyping.model_rebuild()
types.UpdateChatParticipants.model_rebuild()
types.UpdateUserStatus.model_rebuild()
types.UpdateUserName.model_rebuild()
types.UpdateNewAuthorization.model_rebuild()
types.UpdateNewEncryptedMessage.model_rebuild()
types.UpdateEncryptedChatTyping.model_rebuild()
types.UpdateEncryption.model_rebuild()
types.UpdateEncryptedMessagesRead.model_rebuild()
types.UpdateChatParticipantAdd.model_rebuild()
types.UpdateChatParticipantDelete.model_rebuild()
types.UpdateDcOptions.model_rebuild()
types.UpdateNotifySettings.model_rebuild()
types.UpdateServiceNotification.model_rebuild()
types.UpdatePrivacy.model_rebuild()
types.UpdateUserPhone.model_rebuild()
types.UpdateReadHistoryInbox.model_rebuild()
types.UpdateReadHistoryOutbox.model_rebuild()
types.UpdateWebPage.model_rebuild()
types.UpdateReadMessagesContents.model_rebuild()
types.UpdateChannelTooLong.model_rebuild()
types.UpdateChannel.model_rebuild()
types.UpdateNewChannelMessage.model_rebuild()
types.UpdateReadChannelInbox.model_rebuild()
types.UpdateDeleteChannelMessages.model_rebuild()
types.UpdateChannelMessageViews.model_rebuild()
types.UpdateChatParticipantAdmin.model_rebuild()
types.UpdateNewStickerSet.model_rebuild()
types.UpdateStickerSetsOrder.model_rebuild()
types.UpdateStickerSets.model_rebuild()
types.UpdateSavedGifs.model_rebuild()
types.UpdateBotInlineQuery.model_rebuild()
types.UpdateBotInlineSend.model_rebuild()
types.UpdateEditChannelMessage.model_rebuild()
types.UpdateBotCallbackQuery.model_rebuild()
types.UpdateEditMessage.model_rebuild()
types.UpdateInlineBotCallbackQuery.model_rebuild()
types.UpdateReadChannelOutbox.model_rebuild()
types.UpdateDraftMessage.model_rebuild()
types.UpdateReadFeaturedStickers.model_rebuild()
types.UpdateRecentStickers.model_rebuild()
types.UpdateConfig.model_rebuild()
types.UpdatePtsChanged.model_rebuild()
types.UpdateChannelWebPage.model_rebuild()
types.UpdateDialogPinned.model_rebuild()
types.UpdatePinnedDialogs.model_rebuild()
types.UpdateBotWebhookJSON.model_rebuild()
types.UpdateBotWebhookJSONQuery.model_rebuild()
types.UpdateBotShippingQuery.model_rebuild()
types.UpdateBotPrecheckoutQuery.model_rebuild()
types.UpdatePhoneCall.model_rebuild()
types.UpdateLangPackTooLong.model_rebuild()
types.UpdateLangPack.model_rebuild()
types.UpdateFavedStickers.model_rebuild()
types.UpdateChannelReadMessagesContents.model_rebuild()
types.UpdateContactsReset.model_rebuild()
types.UpdateChannelAvailableMessages.model_rebuild()
types.UpdateDialogUnreadMark.model_rebuild()
types.UpdateMessagePoll.model_rebuild()
types.UpdateChatDefaultBannedRights.model_rebuild()
types.UpdateFolderPeers.model_rebuild()
types.UpdatePeerSettings.model_rebuild()
types.UpdatePeerLocated.model_rebuild()
types.UpdateNewScheduledMessage.model_rebuild()
types.UpdateDeleteScheduledMessages.model_rebuild()
types.UpdateTheme.model_rebuild()
types.UpdateGeoLiveViewed.model_rebuild()
types.UpdateLoginToken.model_rebuild()
types.UpdateMessagePollVote.model_rebuild()
types.UpdateDialogFilter.model_rebuild()
types.UpdateDialogFilterOrder.model_rebuild()
types.UpdateDialogFilters.model_rebuild()
types.UpdatePhoneCallSignalingData.model_rebuild()
types.UpdateChannelMessageForwards.model_rebuild()
types.UpdateReadChannelDiscussionInbox.model_rebuild()
types.UpdateReadChannelDiscussionOutbox.model_rebuild()
types.UpdatePeerBlocked.model_rebuild()
types.UpdateChannelUserTyping.model_rebuild()
types.UpdatePinnedMessages.model_rebuild()
types.UpdatePinnedChannelMessages.model_rebuild()
types.UpdateChat.model_rebuild()
types.UpdateGroupCallParticipants.model_rebuild()
types.UpdateGroupCall.model_rebuild()
types.UpdatePeerHistoryTTL.model_rebuild()
types.UpdateChatParticipant.model_rebuild()
types.UpdateChannelParticipant.model_rebuild()
types.UpdateBotStopped.model_rebuild()
types.UpdateGroupCallConnection.model_rebuild()
types.UpdateBotCommands.model_rebuild()
types.UpdatePendingJoinRequests.model_rebuild()
types.UpdateBotChatInviteRequester.model_rebuild()
types.UpdateMessageReactions.model_rebuild()
types.UpdateAttachMenuBots.model_rebuild()
types.UpdateWebViewResultSent.model_rebuild()
types.UpdateBotMenuButton.model_rebuild()
types.UpdateSavedRingtones.model_rebuild()
types.UpdateTranscribedAudio.model_rebuild()
types.UpdateReadFeaturedEmojiStickers.model_rebuild()
types.UpdateUserEmojiStatus.model_rebuild()
types.UpdateRecentEmojiStatuses.model_rebuild()
types.UpdateRecentReactions.model_rebuild()
types.UpdateMoveStickerSetToTop.model_rebuild()
types.UpdateMessageExtendedMedia.model_rebuild()
types.UpdateChannelPinnedTopic.model_rebuild()
types.UpdateChannelPinnedTopics.model_rebuild()
types.UpdateUser.model_rebuild()
types.UpdateAutoSaveSettings.model_rebuild()
types.UpdateStory.model_rebuild()
types.UpdateReadStories.model_rebuild()
types.UpdateStoryID.model_rebuild()
types.UpdateStoriesStealthMode.model_rebuild()
types.UpdateSentStoryReaction.model_rebuild()
types.UpdateBotChatBoost.model_rebuild()
types.UpdateChannelViewForumAsMessages.model_rebuild()
types.UpdatePeerWallpaper.model_rebuild()
types.UpdateBotMessageReaction.model_rebuild()
types.UpdateBotMessageReactions.model_rebuild()
types.UpdateSavedDialogPinned.model_rebuild()
types.UpdatePinnedSavedDialogs.model_rebuild()
types.UpdateSavedReactionTags.model_rebuild()
types.UpdateSmsJob.model_rebuild()
types.UpdateQuickReplies.model_rebuild()
types.UpdateNewQuickReply.model_rebuild()
types.UpdateDeleteQuickReply.model_rebuild()
types.UpdateQuickReplyMessage.model_rebuild()
types.UpdateDeleteQuickReplyMessages.model_rebuild()
types.UpdateBotBusinessConnect.model_rebuild()
types.UpdateBotNewBusinessMessage.model_rebuild()
types.UpdateBotEditBusinessMessage.model_rebuild()
types.UpdateBotDeleteBusinessMessage.model_rebuild()
types.UpdateNewStoryReaction.model_rebuild()
types.UpdateBroadcastRevenueTransactions.model_rebuild()
types.UpdateStarsBalance.model_rebuild()
types.UpdatesTooLong.model_rebuild()
types.UpdateShortMessage.model_rebuild()
types.UpdateShortChatMessage.model_rebuild()
types.UpdateShort.model_rebuild()
types.UpdatesCombined.model_rebuild()
types.Updates.model_rebuild()
types.UpdateShortSentMessage.model_rebuild()
types.DcOption.model_rebuild()
types.Config.model_rebuild()
types.NearestDc.model_rebuild()
types.EncryptedChatEmpty.model_rebuild()
types.EncryptedChatWaiting.model_rebuild()
types.EncryptedChatRequested.model_rebuild()
types.EncryptedChat.model_rebuild()
types.EncryptedChatDiscarded.model_rebuild()
types.InputEncryptedChat.model_rebuild()
types.EncryptedFileEmpty.model_rebuild()
types.EncryptedFile.model_rebuild()
types.InputEncryptedFileEmpty.model_rebuild()
types.InputEncryptedFileUploaded.model_rebuild()
types.InputEncryptedFile.model_rebuild()
types.InputEncryptedFileBigUploaded.model_rebuild()
types.EncryptedMessage.model_rebuild()
types.EncryptedMessageService.model_rebuild()
types.InputDocumentEmpty.model_rebuild()
types.InputDocument.model_rebuild()
types.DocumentEmpty.model_rebuild()
types.Document.model_rebuild()
types.NotifyPeer.model_rebuild()
types.NotifyUsers.model_rebuild()
types.NotifyChats.model_rebuild()
types.NotifyBroadcasts.model_rebuild()
types.NotifyForumTopic.model_rebuild()
types.SendMessageTypingAction.model_rebuild()
types.SendMessageCancelAction.model_rebuild()
types.SendMessageRecordVideoAction.model_rebuild()
types.SendMessageUploadVideoAction.model_rebuild()
types.SendMessageRecordAudioAction.model_rebuild()
types.SendMessageUploadAudioAction.model_rebuild()
types.SendMessageUploadPhotoAction.model_rebuild()
types.SendMessageUploadDocumentAction.model_rebuild()
types.SendMessageGeoLocationAction.model_rebuild()
types.SendMessageChooseContactAction.model_rebuild()
types.SendMessageGamePlayAction.model_rebuild()
types.SendMessageRecordRoundAction.model_rebuild()
types.SendMessageUploadRoundAction.model_rebuild()
types.SpeakingInGroupCallAction.model_rebuild()
types.SendMessageHistoryImportAction.model_rebuild()
types.SendMessageChooseStickerAction.model_rebuild()
types.SendMessageEmojiInteraction.model_rebuild()
types.SendMessageEmojiInteractionSeen.model_rebuild()
types.InputPrivacyKeyStatusTimestamp.model_rebuild()
types.InputPrivacyKeyChatInvite.model_rebuild()
types.InputPrivacyKeyPhoneCall.model_rebuild()
types.InputPrivacyKeyPhoneP2P.model_rebuild()
types.InputPrivacyKeyForwards.model_rebuild()
types.InputPrivacyKeyProfilePhoto.model_rebuild()
types.InputPrivacyKeyPhoneNumber.model_rebuild()
types.InputPrivacyKeyAddedByPhone.model_rebuild()
types.InputPrivacyKeyVoiceMessages.model_rebuild()
types.InputPrivacyKeyAbout.model_rebuild()
types.InputPrivacyKeyBirthday.model_rebuild()
types.PrivacyKeyStatusTimestamp.model_rebuild()
types.PrivacyKeyChatInvite.model_rebuild()
types.PrivacyKeyPhoneCall.model_rebuild()
types.PrivacyKeyPhoneP2P.model_rebuild()
types.PrivacyKeyForwards.model_rebuild()
types.PrivacyKeyProfilePhoto.model_rebuild()
types.PrivacyKeyPhoneNumber.model_rebuild()
types.PrivacyKeyAddedByPhone.model_rebuild()
types.PrivacyKeyVoiceMessages.model_rebuild()
types.PrivacyKeyAbout.model_rebuild()
types.PrivacyKeyBirthday.model_rebuild()
types.InputPrivacyValueAllowContacts.model_rebuild()
types.InputPrivacyValueAllowAll.model_rebuild()
types.InputPrivacyValueAllowUsers.model_rebuild()
types.InputPrivacyValueDisallowContacts.model_rebuild()
types.InputPrivacyValueDisallowAll.model_rebuild()
types.InputPrivacyValueDisallowUsers.model_rebuild()
types.InputPrivacyValueAllowChatParticipants.model_rebuild()
types.InputPrivacyValueDisallowChatParticipants.model_rebuild()
types.InputPrivacyValueAllowCloseFriends.model_rebuild()
types.InputPrivacyValueAllowPremium.model_rebuild()
types.PrivacyValueAllowContacts.model_rebuild()
types.PrivacyValueAllowAll.model_rebuild()
types.PrivacyValueAllowUsers.model_rebuild()
types.PrivacyValueDisallowContacts.model_rebuild()
types.PrivacyValueDisallowAll.model_rebuild()
types.PrivacyValueDisallowUsers.model_rebuild()
types.PrivacyValueAllowChatParticipants.model_rebuild()
types.PrivacyValueDisallowChatParticipants.model_rebuild()
types.PrivacyValueAllowCloseFriends.model_rebuild()
types.PrivacyValueAllowPremium.model_rebuild()
types.AccountDaysTTL.model_rebuild()
types.DocumentAttributeImageSize.model_rebuild()
types.DocumentAttributeAnimated.model_rebuild()
types.DocumentAttributeSticker.model_rebuild()
types.DocumentAttributeVideo.model_rebuild()
types.DocumentAttributeAudio.model_rebuild()
types.DocumentAttributeFilename.model_rebuild()
types.DocumentAttributeHasStickers.model_rebuild()
types.DocumentAttributeCustomEmoji.model_rebuild()
types.StickerPack.model_rebuild()
types.WebPageEmpty.model_rebuild()
types.WebPagePending.model_rebuild()
types.WebPage.model_rebuild()
types.WebPageNotModified.model_rebuild()
types.Authorization.model_rebuild()
types.ReceivedNotifyMessage.model_rebuild()
types.ChatInviteExported.model_rebuild()
types.ChatInvitePublicJoinRequests.model_rebuild()
types.ChatInviteAlready.model_rebuild()
types.ChatInvite.model_rebuild()
types.ChatInvitePeek.model_rebuild()
types.InputStickerSetEmpty.model_rebuild()
types.InputStickerSetID.model_rebuild()
types.InputStickerSetShortName.model_rebuild()
types.InputStickerSetAnimatedEmoji.model_rebuild()
types.InputStickerSetDice.model_rebuild()
types.InputStickerSetAnimatedEmojiAnimations.model_rebuild()
types.InputStickerSetPremiumGifts.model_rebuild()
types.InputStickerSetEmojiGenericAnimations.model_rebuild()
types.InputStickerSetEmojiDefaultStatuses.model_rebuild()
types.InputStickerSetEmojiDefaultTopicIcons.model_rebuild()
types.InputStickerSetEmojiChannelDefaultStatuses.model_rebuild()
types.StickerSet.model_rebuild()
types.BotCommand.model_rebuild()
types.BotInfo.model_rebuild()
types.KeyboardButton.model_rebuild()
types.KeyboardButtonUrl.model_rebuild()
types.KeyboardButtonCallback.model_rebuild()
types.KeyboardButtonRequestPhone.model_rebuild()
types.KeyboardButtonRequestGeoLocation.model_rebuild()
types.KeyboardButtonSwitchInline.model_rebuild()
types.KeyboardButtonGame.model_rebuild()
types.KeyboardButtonBuy.model_rebuild()
types.KeyboardButtonUrlAuth.model_rebuild()
types.InputKeyboardButtonUrlAuth.model_rebuild()
types.KeyboardButtonRequestPoll.model_rebuild()
types.InputKeyboardButtonUserProfile.model_rebuild()
types.KeyboardButtonUserProfile.model_rebuild()
types.KeyboardButtonWebView.model_rebuild()
types.KeyboardButtonSimpleWebView.model_rebuild()
types.KeyboardButtonRequestPeer.model_rebuild()
types.InputKeyboardButtonRequestPeer.model_rebuild()
types.KeyboardButtonRow.model_rebuild()
types.ReplyKeyboardHide.model_rebuild()
types.ReplyKeyboardForceReply.model_rebuild()
types.ReplyKeyboardMarkup.model_rebuild()
types.ReplyInlineMarkup.model_rebuild()
types.MessageEntityUnknown.model_rebuild()
types.MessageEntityMention.model_rebuild()
types.MessageEntityHashtag.model_rebuild()
types.MessageEntityBotCommand.model_rebuild()
types.MessageEntityUrl.model_rebuild()
types.MessageEntityEmail.model_rebuild()
types.MessageEntityBold.model_rebuild()
types.MessageEntityItalic.model_rebuild()
types.MessageEntityCode.model_rebuild()
types.MessageEntityPre.model_rebuild()
types.MessageEntityTextUrl.model_rebuild()
types.MessageEntityMentionName.model_rebuild()
types.InputMessageEntityMentionName.model_rebuild()
types.MessageEntityPhone.model_rebuild()
types.MessageEntityCashtag.model_rebuild()
types.MessageEntityUnderline.model_rebuild()
types.MessageEntityStrike.model_rebuild()
types.MessageEntityBankCard.model_rebuild()
types.MessageEntitySpoiler.model_rebuild()
types.MessageEntityCustomEmoji.model_rebuild()
types.MessageEntityBlockquote.model_rebuild()
types.InputChannelEmpty.model_rebuild()
types.InputChannel.model_rebuild()
types.InputChannelFromMessage.model_rebuild()
types.MessageRange.model_rebuild()
types.ChannelMessagesFilterEmpty.model_rebuild()
types.ChannelMessagesFilter.model_rebuild()
types.ChannelParticipant.model_rebuild()
types.ChannelParticipantSelf.model_rebuild()
types.ChannelParticipantCreator.model_rebuild()
types.ChannelParticipantAdmin.model_rebuild()
types.ChannelParticipantBanned.model_rebuild()
types.ChannelParticipantLeft.model_rebuild()
types.ChannelParticipantsRecent.model_rebuild()
types.ChannelParticipantsAdmins.model_rebuild()
types.ChannelParticipantsKicked.model_rebuild()
types.ChannelParticipantsBots.model_rebuild()
types.ChannelParticipantsBanned.model_rebuild()
types.ChannelParticipantsSearch.model_rebuild()
types.ChannelParticipantsContacts.model_rebuild()
types.ChannelParticipantsMentions.model_rebuild()
types.InputBotInlineMessageMediaAuto.model_rebuild()
types.InputBotInlineMessageText.model_rebuild()
types.InputBotInlineMessageMediaGeo.model_rebuild()
types.InputBotInlineMessageMediaVenue.model_rebuild()
types.InputBotInlineMessageMediaContact.model_rebuild()
types.InputBotInlineMessageGame.model_rebuild()
types.InputBotInlineMessageMediaInvoice.model_rebuild()
types.InputBotInlineMessageMediaWebPage.model_rebuild()
types.InputBotInlineResult.model_rebuild()
types.InputBotInlineResultPhoto.model_rebuild()
types.InputBotInlineResultDocument.model_rebuild()
types.InputBotInlineResultGame.model_rebuild()
types.BotInlineMessageMediaAuto.model_rebuild()
types.BotInlineMessageText.model_rebuild()
types.BotInlineMessageMediaGeo.model_rebuild()
types.BotInlineMessageMediaVenue.model_rebuild()
types.BotInlineMessageMediaContact.model_rebuild()
types.BotInlineMessageMediaInvoice.model_rebuild()
types.BotInlineMessageMediaWebPage.model_rebuild()
types.BotInlineResult.model_rebuild()
types.BotInlineMediaResult.model_rebuild()
types.ExportedMessageLink.model_rebuild()
types.MessageFwdHeader.model_rebuild()
types.InputBotInlineMessageID.model_rebuild()
types.InputBotInlineMessageID64.model_rebuild()
types.InlineBotSwitchPM.model_rebuild()
types.TopPeer.model_rebuild()
types.TopPeerCategoryBotsPM.model_rebuild()
types.TopPeerCategoryBotsInline.model_rebuild()
types.TopPeerCategoryCorrespondents.model_rebuild()
types.TopPeerCategoryGroups.model_rebuild()
types.TopPeerCategoryChannels.model_rebuild()
types.TopPeerCategoryPhoneCalls.model_rebuild()
types.TopPeerCategoryForwardUsers.model_rebuild()
types.TopPeerCategoryForwardChats.model_rebuild()
types.TopPeerCategoryPeers.model_rebuild()
types.DraftMessageEmpty.model_rebuild()
types.DraftMessage.model_rebuild()
types.StickerSetCovered.model_rebuild()
types.StickerSetMultiCovered.model_rebuild()
types.StickerSetFullCovered.model_rebuild()
types.StickerSetNoCovered.model_rebuild()
types.MaskCoords.model_rebuild()
types.InputStickeredMediaPhoto.model_rebuild()
types.InputStickeredMediaDocument.model_rebuild()
types.Game.model_rebuild()
types.InputGameID.model_rebuild()
types.InputGameShortName.model_rebuild()
types.HighScore.model_rebuild()
types.TextEmpty.model_rebuild()
types.TextPlain.model_rebuild()
types.TextBold.model_rebuild()
types.TextItalic.model_rebuild()
types.TextUnderline.model_rebuild()
types.TextStrike.model_rebuild()
types.TextFixed.model_rebuild()
types.TextUrl.model_rebuild()
types.TextEmail.model_rebuild()
types.TextConcat.model_rebuild()
types.TextSubscript.model_rebuild()
types.TextSuperscript.model_rebuild()
types.TextMarked.model_rebuild()
types.TextPhone.model_rebuild()
types.TextImage.model_rebuild()
types.TextAnchor.model_rebuild()
types.PageBlockUnsupported.model_rebuild()
types.PageBlockTitle.model_rebuild()
types.PageBlockSubtitle.model_rebuild()
types.PageBlockAuthorDate.model_rebuild()
types.PageBlockHeader.model_rebuild()
types.PageBlockSubheader.model_rebuild()
types.PageBlockParagraph.model_rebuild()
types.PageBlockPreformatted.model_rebuild()
types.PageBlockFooter.model_rebuild()
types.PageBlockDivider.model_rebuild()
types.PageBlockAnchor.model_rebuild()
types.PageBlockList.model_rebuild()
types.PageBlockBlockquote.model_rebuild()
types.PageBlockPullquote.model_rebuild()
types.PageBlockPhoto.model_rebuild()
types.PageBlockVideo.model_rebuild()
types.PageBlockCover.model_rebuild()
types.PageBlockEmbed.model_rebuild()
types.PageBlockEmbedPost.model_rebuild()
types.PageBlockCollage.model_rebuild()
types.PageBlockSlideshow.model_rebuild()
types.PageBlockChannel.model_rebuild()
types.PageBlockAudio.model_rebuild()
types.PageBlockKicker.model_rebuild()
types.PageBlockTable.model_rebuild()
types.PageBlockOrderedList.model_rebuild()
types.PageBlockDetails.model_rebuild()
types.PageBlockRelatedArticles.model_rebuild()
types.PageBlockMap.model_rebuild()
types.PhoneCallDiscardReasonMissed.model_rebuild()
types.PhoneCallDiscardReasonDisconnect.model_rebuild()
types.PhoneCallDiscardReasonHangup.model_rebuild()
types.PhoneCallDiscardReasonBusy.model_rebuild()
types.DataJSON.model_rebuild()
types.LabeledPrice.model_rebuild()
types.Invoice.model_rebuild()
types.PaymentCharge.model_rebuild()
types.PostAddress.model_rebuild()
types.PaymentRequestedInfo.model_rebuild()
types.PaymentSavedCredentialsCard.model_rebuild()
types.WebDocument.model_rebuild()
types.WebDocumentNoProxy.model_rebuild()
types.InputWebDocument.model_rebuild()
types.InputWebFileLocation.model_rebuild()
types.InputWebFileGeoPointLocation.model_rebuild()
types.InputWebFileAudioAlbumThumbLocation.model_rebuild()
types.InputPaymentCredentialsSaved.model_rebuild()
types.InputPaymentCredentials.model_rebuild()
types.InputPaymentCredentialsApplePay.model_rebuild()
types.InputPaymentCredentialsGooglePay.model_rebuild()
types.ShippingOption.model_rebuild()
types.InputStickerSetItem.model_rebuild()
types.InputPhoneCall.model_rebuild()
types.PhoneCallEmpty.model_rebuild()
types.PhoneCallWaiting.model_rebuild()
types.PhoneCallRequested.model_rebuild()
types.PhoneCallAccepted.model_rebuild()
types.PhoneCall.model_rebuild()
types.PhoneCallDiscarded.model_rebuild()
types.PhoneConnection.model_rebuild()
types.PhoneConnectionWebrtc.model_rebuild()
types.PhoneCallProtocol.model_rebuild()
types.CdnPublicKey.model_rebuild()
types.CdnConfig.model_rebuild()
types.LangPackString.model_rebuild()
types.LangPackStringPluralized.model_rebuild()
types.LangPackStringDeleted.model_rebuild()
types.LangPackDifference.model_rebuild()
types.LangPackLanguage.model_rebuild()
types.ChannelAdminLogEventActionChangeTitle.model_rebuild()
types.ChannelAdminLogEventActionChangeAbout.model_rebuild()
types.ChannelAdminLogEventActionChangeUsername.model_rebuild()
types.ChannelAdminLogEventActionChangePhoto.model_rebuild()
types.ChannelAdminLogEventActionToggleInvites.model_rebuild()
types.ChannelAdminLogEventActionToggleSignatures.model_rebuild()
types.ChannelAdminLogEventActionUpdatePinned.model_rebuild()
types.ChannelAdminLogEventActionEditMessage.model_rebuild()
types.ChannelAdminLogEventActionDeleteMessage.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoin.model_rebuild()
types.ChannelAdminLogEventActionParticipantLeave.model_rebuild()
types.ChannelAdminLogEventActionParticipantInvite.model_rebuild()
types.ChannelAdminLogEventActionParticipantToggleBan.model_rebuild()
types.ChannelAdminLogEventActionParticipantToggleAdmin.model_rebuild()
types.ChannelAdminLogEventActionChangeStickerSet.model_rebuild()
types.ChannelAdminLogEventActionTogglePreHistoryHidden.model_rebuild()
types.ChannelAdminLogEventActionDefaultBannedRights.model_rebuild()
types.ChannelAdminLogEventActionStopPoll.model_rebuild()
types.ChannelAdminLogEventActionChangeLinkedChat.model_rebuild()
types.ChannelAdminLogEventActionChangeLocation.model_rebuild()
types.ChannelAdminLogEventActionToggleSlowMode.model_rebuild()
types.ChannelAdminLogEventActionStartGroupCall.model_rebuild()
types.ChannelAdminLogEventActionDiscardGroupCall.model_rebuild()
types.ChannelAdminLogEventActionParticipantMute.model_rebuild()
types.ChannelAdminLogEventActionParticipantUnmute.model_rebuild()
types.ChannelAdminLogEventActionToggleGroupCallSetting.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoinByInvite.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteDelete.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteRevoke.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteEdit.model_rebuild()
types.ChannelAdminLogEventActionParticipantVolume.model_rebuild()
types.ChannelAdminLogEventActionChangeHistoryTTL.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoinByRequest.model_rebuild()
types.ChannelAdminLogEventActionToggleNoForwards.model_rebuild()
types.ChannelAdminLogEventActionSendMessage.model_rebuild()
types.ChannelAdminLogEventActionChangeAvailableReactions.model_rebuild()
types.ChannelAdminLogEventActionChangeUsernames.model_rebuild()
types.ChannelAdminLogEventActionToggleForum.model_rebuild()
types.ChannelAdminLogEventActionCreateTopic.model_rebuild()
types.ChannelAdminLogEventActionEditTopic.model_rebuild()
types.ChannelAdminLogEventActionDeleteTopic.model_rebuild()
types.ChannelAdminLogEventActionPinTopic.model_rebuild()
types.ChannelAdminLogEventActionToggleAntiSpam.model_rebuild()
types.ChannelAdminLogEventActionChangePeerColor.model_rebuild()
types.ChannelAdminLogEventActionChangeProfilePeerColor.model_rebuild()
types.ChannelAdminLogEventActionChangeWallpaper.model_rebuild()
types.ChannelAdminLogEventActionChangeEmojiStatus.model_rebuild()
types.ChannelAdminLogEventActionChangeEmojiStickerSet.model_rebuild()
types.ChannelAdminLogEvent.model_rebuild()
types.ChannelAdminLogEventsFilter.model_rebuild()
types.PopularContact.model_rebuild()
types.RecentMeUrlUnknown.model_rebuild()
types.RecentMeUrlUser.model_rebuild()
types.RecentMeUrlChat.model_rebuild()
types.RecentMeUrlChatInvite.model_rebuild()
types.RecentMeUrlStickerSet.model_rebuild()
types.InputSingleMedia.model_rebuild()
types.WebAuthorization.model_rebuild()
types.InputMessageID.model_rebuild()
types.InputMessageReplyTo.model_rebuild()
types.InputMessagePinned.model_rebuild()
types.InputMessageCallbackQuery.model_rebuild()
types.InputDialogPeer.model_rebuild()
types.InputDialogPeerFolder.model_rebuild()
types.DialogPeer.model_rebuild()
types.DialogPeerFolder.model_rebuild()
types.FileHash.model_rebuild()
types.InputClientProxy.model_rebuild()
types.InputSecureFileUploaded.model_rebuild()
types.InputSecureFile.model_rebuild()
types.SecureFileEmpty.model_rebuild()
types.SecureFile.model_rebuild()
types.SecureData.model_rebuild()
types.SecurePlainPhone.model_rebuild()
types.SecurePlainEmail.model_rebuild()
types.SecureValueTypePersonalDetails.model_rebuild()
types.SecureValueTypePassport.model_rebuild()
types.SecureValueTypeDriverLicense.model_rebuild()
types.SecureValueTypeIdentityCard.model_rebuild()
types.SecureValueTypeInternalPassport.model_rebuild()
types.SecureValueTypeAddress.model_rebuild()
types.SecureValueTypeUtilityBill.model_rebuild()
types.SecureValueTypeBankStatement.model_rebuild()
types.SecureValueTypeRentalAgreement.model_rebuild()
types.SecureValueTypePassportRegistration.model_rebuild()
types.SecureValueTypeTemporaryRegistration.model_rebuild()
types.SecureValueTypePhone.model_rebuild()
types.SecureValueTypeEmail.model_rebuild()
types.SecureValue.model_rebuild()
types.InputSecureValue.model_rebuild()
types.SecureValueHash.model_rebuild()
types.SecureValueErrorData.model_rebuild()
types.SecureValueErrorFrontSide.model_rebuild()
types.SecureValueErrorReverseSide.model_rebuild()
types.SecureValueErrorSelfie.model_rebuild()
types.SecureValueErrorFile.model_rebuild()
types.SecureValueErrorFiles.model_rebuild()
types.SecureValueError.model_rebuild()
types.SecureValueErrorTranslationFile.model_rebuild()
types.SecureValueErrorTranslationFiles.model_rebuild()
types.SecureCredentialsEncrypted.model_rebuild()
types.SavedPhoneContact.model_rebuild()
types.PasswordKdfAlgoUnknown.model_rebuild()
types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow.model_rebuild()
types.SecurePasswordKdfAlgoUnknown.model_rebuild()
types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000.model_rebuild()
types.SecurePasswordKdfAlgoSHA512.model_rebuild()
types.SecureSecretSettings.model_rebuild()
types.InputCheckPasswordEmpty.model_rebuild()
types.InputCheckPasswordSRP.model_rebuild()
types.SecureRequiredType.model_rebuild()
types.SecureRequiredTypeOneOf.model_rebuild()
types.InputAppEvent.model_rebuild()
types.JsonObjectValue.model_rebuild()
types.JsonNull.model_rebuild()
types.JsonBool.model_rebuild()
types.JsonNumber.model_rebuild()
types.JsonString.model_rebuild()
types.JsonArray.model_rebuild()
types.JsonObject.model_rebuild()
types.PageTableCell.model_rebuild()
types.PageTableRow.model_rebuild()
types.PageCaption.model_rebuild()
types.PageListItemText.model_rebuild()
types.PageListItemBlocks.model_rebuild()
types.PageListOrderedItemText.model_rebuild()
types.PageListOrderedItemBlocks.model_rebuild()
types.PageRelatedArticle.model_rebuild()
types.Page.model_rebuild()
types.PollAnswer.model_rebuild()
types.Poll.model_rebuild()
types.PollAnswerVoters.model_rebuild()
types.PollResults.model_rebuild()
types.ChatOnlines.model_rebuild()
types.StatsURL.model_rebuild()
types.ChatAdminRights.model_rebuild()
types.ChatBannedRights.model_rebuild()
types.InputWallPaper.model_rebuild()
types.InputWallPaperSlug.model_rebuild()
types.InputWallPaperNoFile.model_rebuild()
types.CodeSettings.model_rebuild()
types.WallPaperSettings.model_rebuild()
types.AutoDownloadSettings.model_rebuild()
types.EmojiKeyword.model_rebuild()
types.EmojiKeywordDeleted.model_rebuild()
types.EmojiKeywordsDifference.model_rebuild()
types.EmojiURL.model_rebuild()
types.EmojiLanguage.model_rebuild()
types.Folder.model_rebuild()
types.InputFolderPeer.model_rebuild()
types.FolderPeer.model_rebuild()
types.UrlAuthResultRequest.model_rebuild()
types.UrlAuthResultAccepted.model_rebuild()
types.UrlAuthResultDefault.model_rebuild()
types.ChannelLocationEmpty.model_rebuild()
types.ChannelLocation.model_rebuild()
types.PeerLocated.model_rebuild()
types.PeerSelfLocated.model_rebuild()
types.RestrictionReason.model_rebuild()
types.InputTheme.model_rebuild()
types.InputThemeSlug.model_rebuild()
types.Theme.model_rebuild()
types.BaseThemeClassic.model_rebuild()
types.BaseThemeDay.model_rebuild()
types.BaseThemeNight.model_rebuild()
types.BaseThemeTinted.model_rebuild()
types.BaseThemeArctic.model_rebuild()
types.InputThemeSettings.model_rebuild()
types.ThemeSettings.model_rebuild()
types.WebPageAttributeTheme.model_rebuild()
types.WebPageAttributeStory.model_rebuild()
types.WebPageAttributeStickerSet.model_rebuild()
types.BankCardOpenUrl.model_rebuild()
types.DialogFilter.model_rebuild()
types.DialogFilterDefault.model_rebuild()
types.DialogFilterChatlist.model_rebuild()
types.DialogFilterSuggested.model_rebuild()
types.StatsDateRangeDays.model_rebuild()
types.StatsAbsValueAndPrev.model_rebuild()
types.StatsPercentValue.model_rebuild()
types.StatsGraphAsync.model_rebuild()
types.StatsGraphError.model_rebuild()
types.StatsGraph.model_rebuild()
types.VideoSize.model_rebuild()
types.VideoSizeEmojiMarkup.model_rebuild()
types.VideoSizeStickerMarkup.model_rebuild()
types.StatsGroupTopPoster.model_rebuild()
types.StatsGroupTopAdmin.model_rebuild()
types.StatsGroupTopInviter.model_rebuild()
types.GlobalPrivacySettings.model_rebuild()
types.MessageViews.model_rebuild()
types.MessageReplyHeader.model_rebuild()
types.MessageReplyStoryHeader.model_rebuild()
types.MessageReplies.model_rebuild()
types.PeerBlocked.model_rebuild()
types.GroupCallDiscarded.model_rebuild()
types.GroupCall.model_rebuild()
types.InputGroupCall.model_rebuild()
types.GroupCallParticipant.model_rebuild()
types.InlineQueryPeerTypeSameBotPM.model_rebuild()
types.InlineQueryPeerTypePM.model_rebuild()
types.InlineQueryPeerTypeChat.model_rebuild()
types.InlineQueryPeerTypeMegagroup.model_rebuild()
types.InlineQueryPeerTypeBroadcast.model_rebuild()
types.InlineQueryPeerTypeBotPM.model_rebuild()
types.ChatInviteImporter.model_rebuild()
types.ChatAdminWithInvites.model_rebuild()
types.GroupCallParticipantVideoSourceGroup.model_rebuild()
types.GroupCallParticipantVideo.model_rebuild()
types.BotCommandScopeDefault.model_rebuild()
types.BotCommandScopeUsers.model_rebuild()
types.BotCommandScopeChats.model_rebuild()
types.BotCommandScopeChatAdmins.model_rebuild()
types.BotCommandScopePeer.model_rebuild()
types.BotCommandScopePeerAdmins.model_rebuild()
types.BotCommandScopePeerUser.model_rebuild()
types.SponsoredMessage.model_rebuild()
types.SearchResultsCalendarPeriod.model_rebuild()
types.SearchResultPosition.model_rebuild()
types.ReactionCount.model_rebuild()
types.MessageReactions.model_rebuild()
types.AvailableReaction.model_rebuild()
types.MessagePeerReaction.model_rebuild()
types.GroupCallStreamChannel.model_rebuild()
types.AttachMenuBotIconColor.model_rebuild()
types.AttachMenuBotIcon.model_rebuild()
types.AttachMenuBot.model_rebuild()
types.AttachMenuBotsNotModified.model_rebuild()
types.AttachMenuBots.model_rebuild()
types.AttachMenuBotsBot.model_rebuild()
types.WebViewResultUrl.model_rebuild()
types.SimpleWebViewResultUrl.model_rebuild()
types.WebViewMessageSent.model_rebuild()
types.BotMenuButtonDefault.model_rebuild()
types.BotMenuButtonCommands.model_rebuild()
types.BotMenuButton.model_rebuild()
types.NotificationSoundDefault.model_rebuild()
types.NotificationSoundNone.model_rebuild()
types.NotificationSoundLocal.model_rebuild()
types.NotificationSoundRingtone.model_rebuild()
types.AttachMenuPeerTypeSameBotPM.model_rebuild()
types.AttachMenuPeerTypeBotPM.model_rebuild()
types.AttachMenuPeerTypePM.model_rebuild()
types.AttachMenuPeerTypeChat.model_rebuild()
types.AttachMenuPeerTypeBroadcast.model_rebuild()
types.InputInvoiceMessage.model_rebuild()
types.InputInvoiceSlug.model_rebuild()
types.InputInvoicePremiumGiftCode.model_rebuild()
types.InputInvoiceStars.model_rebuild()
types.InputStorePaymentPremiumSubscription.model_rebuild()
types.InputStorePaymentGiftPremium.model_rebuild()
types.InputStorePaymentPremiumGiftCode.model_rebuild()
types.InputStorePaymentPremiumGiveaway.model_rebuild()
types.InputStorePaymentStars.model_rebuild()
types.PremiumGiftOption.model_rebuild()
types.PaymentFormMethod.model_rebuild()
types.EmojiStatusEmpty.model_rebuild()
types.EmojiStatus.model_rebuild()
types.EmojiStatusUntil.model_rebuild()
types.ReactionEmpty.model_rebuild()
types.ReactionEmoji.model_rebuild()
types.ReactionCustomEmoji.model_rebuild()
types.ChatReactionsNone.model_rebuild()
types.ChatReactionsAll.model_rebuild()
types.ChatReactionsSome.model_rebuild()
types.EmailVerifyPurposeLoginSetup.model_rebuild()
types.EmailVerifyPurposeLoginChange.model_rebuild()
types.EmailVerifyPurposePassport.model_rebuild()
types.EmailVerificationCode.model_rebuild()
types.EmailVerificationGoogle.model_rebuild()
types.EmailVerificationApple.model_rebuild()
types.PremiumSubscriptionOption.model_rebuild()
types.SendAsPeer.model_rebuild()
types.MessageExtendedMediaPreview.model_rebuild()
types.MessageExtendedMedia.model_rebuild()
types.StickerKeyword.model_rebuild()
types.Username.model_rebuild()
types.ForumTopicDeleted.model_rebuild()
types.ForumTopic.model_rebuild()
types.DefaultHistoryTTL.model_rebuild()
types.ExportedContactToken.model_rebuild()
types.RequestPeerTypeUser.model_rebuild()
types.RequestPeerTypeChat.model_rebuild()
types.RequestPeerTypeBroadcast.model_rebuild()
types.EmojiListNotModified.model_rebuild()
types.EmojiList.model_rebuild()
types.EmojiGroup.model_rebuild()
types.EmojiGroupGreeting.model_rebuild()
types.EmojiGroupPremium.model_rebuild()
types.TextWithEntities.model_rebuild()
types.AutoSaveSettings.model_rebuild()
types.AutoSaveException.model_rebuild()
types.InputBotAppID.model_rebuild()
types.InputBotAppShortName.model_rebuild()
types.BotAppNotModified.model_rebuild()
types.BotApp.model_rebuild()
types.AppWebViewResultUrl.model_rebuild()
types.InlineBotWebView.model_rebuild()
types.ReadParticipantDate.model_rebuild()
types.InputChatlistDialogFilter.model_rebuild()
types.ExportedChatlistInvite.model_rebuild()
types.MessagePeerVote.model_rebuild()
types.MessagePeerVoteInputOption.model_rebuild()
types.MessagePeerVoteMultiple.model_rebuild()
types.StoryViews.model_rebuild()
types.StoryItemDeleted.model_rebuild()
types.StoryItemSkipped.model_rebuild()
types.StoryItem.model_rebuild()
types.StoryView.model_rebuild()
types.StoryViewPublicForward.model_rebuild()
types.StoryViewPublicRepost.model_rebuild()
types.InputReplyToMessage.model_rebuild()
types.InputReplyToStory.model_rebuild()
types.ExportedStoryLink.model_rebuild()
types.StoriesStealthMode.model_rebuild()
types.MediaAreaCoordinates.model_rebuild()
types.MediaAreaVenue.model_rebuild()
types.InputMediaAreaVenue.model_rebuild()
types.MediaAreaGeoPoint.model_rebuild()
types.MediaAreaSuggestedReaction.model_rebuild()
types.MediaAreaChannelPost.model_rebuild()
types.InputMediaAreaChannelPost.model_rebuild()
types.PeerStories.model_rebuild()
types.PremiumGiftCodeOption.model_rebuild()
types.PrepaidGiveaway.model_rebuild()
types.Boost.model_rebuild()
types.MyBoost.model_rebuild()
types.StoryFwdHeader.model_rebuild()
types.PostInteractionCountersMessage.model_rebuild()
types.PostInteractionCountersStory.model_rebuild()
types.PublicForwardMessage.model_rebuild()
types.PublicForwardStory.model_rebuild()
types.PeerColor.model_rebuild()
types.StoryReaction.model_rebuild()
types.StoryReactionPublicForward.model_rebuild()
types.StoryReactionPublicRepost.model_rebuild()
types.SavedDialog.model_rebuild()
types.SavedReactionTag.model_rebuild()
types.OutboxReadDate.model_rebuild()
types.SmsJob.model_rebuild()
types.BusinessWeeklyOpen.model_rebuild()
types.BusinessWorkHours.model_rebuild()
types.BusinessLocation.model_rebuild()
types.InputBusinessRecipients.model_rebuild()
types.BusinessRecipients.model_rebuild()
types.BusinessAwayMessageScheduleAlways.model_rebuild()
types.BusinessAwayMessageScheduleOutsideWorkHours.model_rebuild()
types.BusinessAwayMessageScheduleCustom.model_rebuild()
types.InputBusinessGreetingMessage.model_rebuild()
types.BusinessGreetingMessage.model_rebuild()
types.InputBusinessAwayMessage.model_rebuild()
types.BusinessAwayMessage.model_rebuild()
types.Timezone.model_rebuild()
types.QuickReply.model_rebuild()
types.InputQuickReplyShortcut.model_rebuild()
types.InputQuickReplyShortcutId.model_rebuild()
types.ConnectedBot.model_rebuild()
types.Birthday.model_rebuild()
types.BotBusinessConnection.model_rebuild()
types.InputBusinessIntro.model_rebuild()
types.BusinessIntro.model_rebuild()
types.InputCollectibleUsername.model_rebuild()
types.InputCollectiblePhone.model_rebuild()
types.InputBusinessBotRecipients.model_rebuild()
types.BusinessBotRecipients.model_rebuild()
types.ContactBirthday.model_rebuild()
types.MissingInvitee.model_rebuild()
types.InputBusinessChatLink.model_rebuild()
types.BusinessChatLink.model_rebuild()
types.RequestedPeerUser.model_rebuild()
types.RequestedPeerChat.model_rebuild()
types.RequestedPeerChannel.model_rebuild()
types.SponsoredMessageReportOption.model_rebuild()
types.BroadcastRevenueTransactionProceeds.model_rebuild()
types.BroadcastRevenueTransactionWithdrawal.model_rebuild()
types.BroadcastRevenueTransactionRefund.model_rebuild()
types.ReactionNotificationsFromContacts.model_rebuild()
types.ReactionNotificationsFromAll.model_rebuild()
types.ReactionsNotifySettings.model_rebuild()
types.BroadcastRevenueBalances.model_rebuild()
types.AvailableEffect.model_rebuild()
types.FactCheck.model_rebuild()
types.StarsTransactionPeerUnsupported.model_rebuild()
types.StarsTransactionPeerAppStore.model_rebuild()
types.StarsTransactionPeerPlayMarket.model_rebuild()
types.StarsTransactionPeerPremiumBot.model_rebuild()
types.StarsTransactionPeerFragment.model_rebuild()
types.StarsTransactionPeer.model_rebuild()
types.StarsTopupOption.model_rebuild()
types.StarsTransaction.model_rebuild()
types.storage.FileUnknown.model_rebuild()
types.storage.FilePartial.model_rebuild()
types.storage.FileJpeg.model_rebuild()
types.storage.FileGif.model_rebuild()
types.storage.FilePng.model_rebuild()
types.storage.FilePdf.model_rebuild()
types.storage.FileMp3.model_rebuild()
types.storage.FileMov.model_rebuild()
types.storage.FileMp4.model_rebuild()
types.storage.FileWebp.model_rebuild()
types.auth.SentCode.model_rebuild()
types.auth.SentCodeSuccess.model_rebuild()
types.auth.Authorization.model_rebuild()
types.auth.AuthorizationSignUpRequired.model_rebuild()
types.auth.ExportedAuthorization.model_rebuild()
types.auth.PasswordRecovery.model_rebuild()
types.auth.CodeTypeSms.model_rebuild()
types.auth.CodeTypeCall.model_rebuild()
types.auth.CodeTypeFlashCall.model_rebuild()
types.auth.CodeTypeMissedCall.model_rebuild()
types.auth.CodeTypeFragmentSms.model_rebuild()
types.auth.SentCodeTypeApp.model_rebuild()
types.auth.SentCodeTypeSms.model_rebuild()
types.auth.SentCodeTypeCall.model_rebuild()
types.auth.SentCodeTypeFlashCall.model_rebuild()
types.auth.SentCodeTypeMissedCall.model_rebuild()
types.auth.SentCodeTypeEmailCode.model_rebuild()
types.auth.SentCodeTypeSetUpEmailRequired.model_rebuild()
types.auth.SentCodeTypeFragmentSms.model_rebuild()
types.auth.SentCodeTypeFirebaseSms.model_rebuild()
types.auth.SentCodeTypeSmsWord.model_rebuild()
types.auth.SentCodeTypeSmsPhrase.model_rebuild()
types.auth.LoginToken.model_rebuild()
types.auth.LoginTokenMigrateTo.model_rebuild()
types.auth.LoginTokenSuccess.model_rebuild()
types.auth.LoggedOut.model_rebuild()
types.contacts.ContactsNotModified.model_rebuild()
types.contacts.Contacts.model_rebuild()
types.contacts.ImportedContacts.model_rebuild()
types.contacts.Blocked.model_rebuild()
types.contacts.BlockedSlice.model_rebuild()
types.contacts.Found.model_rebuild()
types.contacts.ResolvedPeer.model_rebuild()
types.contacts.TopPeersNotModified.model_rebuild()
types.contacts.TopPeers.model_rebuild()
types.contacts.TopPeersDisabled.model_rebuild()
types.contacts.ContactBirthdays.model_rebuild()
types.messages.Dialogs.model_rebuild()
types.messages.DialogsSlice.model_rebuild()
types.messages.DialogsNotModified.model_rebuild()
types.messages.Messages.model_rebuild()
types.messages.MessagesSlice.model_rebuild()
types.messages.ChannelMessages.model_rebuild()
types.messages.MessagesNotModified.model_rebuild()
types.messages.Chats.model_rebuild()
types.messages.ChatsSlice.model_rebuild()
types.messages.ChatFull.model_rebuild()
types.messages.AffectedHistory.model_rebuild()
types.messages.DhConfigNotModified.model_rebuild()
types.messages.DhConfig.model_rebuild()
types.messages.SentEncryptedMessage.model_rebuild()
types.messages.SentEncryptedFile.model_rebuild()
types.messages.StickersNotModified.model_rebuild()
types.messages.Stickers.model_rebuild()
types.messages.AllStickersNotModified.model_rebuild()
types.messages.AllStickers.model_rebuild()
types.messages.AffectedMessages.model_rebuild()
types.messages.StickerSet.model_rebuild()
types.messages.StickerSetNotModified.model_rebuild()
types.messages.SavedGifsNotModified.model_rebuild()
types.messages.SavedGifs.model_rebuild()
types.messages.BotResults.model_rebuild()
types.messages.BotCallbackAnswer.model_rebuild()
types.messages.MessageEditData.model_rebuild()
types.messages.PeerDialogs.model_rebuild()
types.messages.FeaturedStickersNotModified.model_rebuild()
types.messages.FeaturedStickers.model_rebuild()
types.messages.RecentStickersNotModified.model_rebuild()
types.messages.RecentStickers.model_rebuild()
types.messages.ArchivedStickers.model_rebuild()
types.messages.StickerSetInstallResultSuccess.model_rebuild()
types.messages.StickerSetInstallResultArchive.model_rebuild()
types.messages.HighScores.model_rebuild()
types.messages.FavedStickersNotModified.model_rebuild()
types.messages.FavedStickers.model_rebuild()
types.messages.FoundStickerSetsNotModified.model_rebuild()
types.messages.FoundStickerSets.model_rebuild()
types.messages.SearchCounter.model_rebuild()
types.messages.InactiveChats.model_rebuild()
types.messages.VotesList.model_rebuild()
types.messages.MessageViews.model_rebuild()
types.messages.DiscussionMessage.model_rebuild()
types.messages.HistoryImport.model_rebuild()
types.messages.HistoryImportParsed.model_rebuild()
types.messages.AffectedFoundMessages.model_rebuild()
types.messages.ExportedChatInvites.model_rebuild()
types.messages.ExportedChatInvite.model_rebuild()
types.messages.ExportedChatInviteReplaced.model_rebuild()
types.messages.ChatInviteImporters.model_rebuild()
types.messages.ChatAdminsWithInvites.model_rebuild()
types.messages.CheckedHistoryImportPeer.model_rebuild()
types.messages.SponsoredMessages.model_rebuild()
types.messages.SponsoredMessagesEmpty.model_rebuild()
types.messages.SearchResultsCalendar.model_rebuild()
types.messages.SearchResultsPositions.model_rebuild()
types.messages.PeerSettings.model_rebuild()
types.messages.MessageReactionsList.model_rebuild()
types.messages.AvailableReactionsNotModified.model_rebuild()
types.messages.AvailableReactions.model_rebuild()
types.messages.TranscribedAudio.model_rebuild()
types.messages.ReactionsNotModified.model_rebuild()
types.messages.Reactions.model_rebuild()
types.messages.ForumTopics.model_rebuild()
types.messages.EmojiGroupsNotModified.model_rebuild()
types.messages.EmojiGroups.model_rebuild()
types.messages.TranslateResult.model_rebuild()
types.messages.BotApp.model_rebuild()
types.messages.WebPage.model_rebuild()
types.messages.SavedDialogs.model_rebuild()
types.messages.SavedDialogsSlice.model_rebuild()
types.messages.SavedDialogsNotModified.model_rebuild()
types.messages.SavedReactionTagsNotModified.model_rebuild()
types.messages.SavedReactionTags.model_rebuild()
types.messages.QuickReplies.model_rebuild()
types.messages.QuickRepliesNotModified.model_rebuild()
types.messages.DialogFilters.model_rebuild()
types.messages.MyStickers.model_rebuild()
types.messages.InvitedUsers.model_rebuild()
types.messages.AvailableEffectsNotModified.model_rebuild()
types.messages.AvailableEffects.model_rebuild()
types.updates.State.model_rebuild()
types.updates.DifferenceEmpty.model_rebuild()
types.updates.Difference.model_rebuild()
types.updates.DifferenceSlice.model_rebuild()
types.updates.DifferenceTooLong.model_rebuild()
types.updates.ChannelDifferenceEmpty.model_rebuild()
types.updates.ChannelDifferenceTooLong.model_rebuild()
types.updates.ChannelDifference.model_rebuild()
types.photos.Photos.model_rebuild()
types.photos.PhotosSlice.model_rebuild()
types.photos.Photo.model_rebuild()
types.upload.File.model_rebuild()
types.upload.FileCdnRedirect.model_rebuild()
types.upload.WebFile.model_rebuild()
types.upload.CdnFileReuploadNeeded.model_rebuild()
types.upload.CdnFile.model_rebuild()
types.help.AppUpdate.model_rebuild()
types.help.NoAppUpdate.model_rebuild()
types.help.InviteText.model_rebuild()
types.help.Support.model_rebuild()
types.help.TermsOfService.model_rebuild()
types.help.RecentMeUrls.model_rebuild()
types.help.TermsOfServiceUpdateEmpty.model_rebuild()
types.help.TermsOfServiceUpdate.model_rebuild()
types.help.DeepLinkInfoEmpty.model_rebuild()
types.help.DeepLinkInfo.model_rebuild()
types.help.PassportConfigNotModified.model_rebuild()
types.help.PassportConfig.model_rebuild()
types.help.SupportName.model_rebuild()
types.help.UserInfoEmpty.model_rebuild()
types.help.UserInfo.model_rebuild()
types.help.PromoDataEmpty.model_rebuild()
types.help.PromoData.model_rebuild()
types.help.CountryCode.model_rebuild()
types.help.Country.model_rebuild()
types.help.CountriesListNotModified.model_rebuild()
types.help.CountriesList.model_rebuild()
types.help.PremiumPromo.model_rebuild()
types.help.AppConfigNotModified.model_rebuild()
types.help.AppConfig.model_rebuild()
types.help.PeerColorSet.model_rebuild()
types.help.PeerColorProfileSet.model_rebuild()
types.help.PeerColorOption.model_rebuild()
types.help.PeerColorsNotModified.model_rebuild()
types.help.PeerColors.model_rebuild()
types.help.TimezonesListNotModified.model_rebuild()
types.help.TimezonesList.model_rebuild()
types.account.PrivacyRules.model_rebuild()
types.account.Authorizations.model_rebuild()
types.account.Password.model_rebuild()
types.account.PasswordSettings.model_rebuild()
types.account.PasswordInputSettings.model_rebuild()
types.account.TmpPassword.model_rebuild()
types.account.WebAuthorizations.model_rebuild()
types.account.AuthorizationForm.model_rebuild()
types.account.SentEmailCode.model_rebuild()
types.account.Takeout.model_rebuild()
types.account.WallPapersNotModified.model_rebuild()
types.account.WallPapers.model_rebuild()
types.account.AutoDownloadSettings.model_rebuild()
types.account.ThemesNotModified.model_rebuild()
types.account.Themes.model_rebuild()
types.account.ContentSettings.model_rebuild()
types.account.ResetPasswordFailedWait.model_rebuild()
types.account.ResetPasswordRequestedWait.model_rebuild()
types.account.ResetPasswordOk.model_rebuild()
types.account.SavedRingtonesNotModified.model_rebuild()
types.account.SavedRingtones.model_rebuild()
types.account.SavedRingtone.model_rebuild()
types.account.SavedRingtoneConverted.model_rebuild()
types.account.EmojiStatusesNotModified.model_rebuild()
types.account.EmojiStatuses.model_rebuild()
types.account.EmailVerified.model_rebuild()
types.account.EmailVerifiedLogin.model_rebuild()
types.account.AutoSaveSettings.model_rebuild()
types.account.ConnectedBots.model_rebuild()
types.account.BusinessChatLinks.model_rebuild()
types.account.ResolvedBusinessChatLinks.model_rebuild()
types.channels.ChannelParticipants.model_rebuild()
types.channels.ChannelParticipantsNotModified.model_rebuild()
types.channels.ChannelParticipant.model_rebuild()
types.channels.AdminLogResults.model_rebuild()
types.channels.SendAsPeers.model_rebuild()
types.channels.SponsoredMessageReportResultChooseOption.model_rebuild()
types.channels.SponsoredMessageReportResultAdsHidden.model_rebuild()
types.channels.SponsoredMessageReportResultReported.model_rebuild()
types.payments.PaymentForm.model_rebuild()
types.payments.PaymentFormStars.model_rebuild()
types.payments.ValidatedRequestedInfo.model_rebuild()
types.payments.PaymentResult.model_rebuild()
types.payments.PaymentVerificationNeeded.model_rebuild()
types.payments.PaymentReceipt.model_rebuild()
types.payments.PaymentReceiptStars.model_rebuild()
types.payments.SavedInfo.model_rebuild()
types.payments.BankCardData.model_rebuild()
types.payments.ExportedInvoice.model_rebuild()
types.payments.CheckedGiftCode.model_rebuild()
types.payments.GiveawayInfo.model_rebuild()
types.payments.GiveawayInfoResults.model_rebuild()
types.payments.StarsStatus.model_rebuild()
types.phone.PhoneCall.model_rebuild()
types.phone.GroupCall.model_rebuild()
types.phone.GroupParticipants.model_rebuild()
types.phone.JoinAsPeers.model_rebuild()
types.phone.ExportedGroupCallInvite.model_rebuild()
types.phone.GroupCallStreamChannels.model_rebuild()
types.phone.GroupCallStreamRtmpUrl.model_rebuild()
types.stats.BroadcastStats.model_rebuild()
types.stats.MegagroupStats.model_rebuild()
types.stats.MessageStats.model_rebuild()
types.stats.StoryStats.model_rebuild()
types.stats.PublicForwards.model_rebuild()
types.stats.BroadcastRevenueStats.model_rebuild()
types.stats.BroadcastRevenueWithdrawalUrl.model_rebuild()
types.stats.BroadcastRevenueTransactions.model_rebuild()
types.stickers.SuggestedShortName.model_rebuild()
types.users.UserFull.model_rebuild()
types.chatlists.ExportedChatlistInvite.model_rebuild()
types.chatlists.ExportedInvites.model_rebuild()
types.chatlists.ChatlistInviteAlready.model_rebuild()
types.chatlists.ChatlistInvite.model_rebuild()
types.chatlists.ChatlistUpdates.model_rebuild()
types.bots.BotInfo.model_rebuild()
types.stories.AllStoriesNotModified.model_rebuild()
types.stories.AllStories.model_rebuild()
types.stories.Stories.model_rebuild()
types.stories.StoryViewsList.model_rebuild()
types.stories.StoryViews.model_rebuild()
types.stories.PeerStories.model_rebuild()
types.stories.StoryReactionsList.model_rebuild()
types.premium.BoostsList.model_rebuild()
types.premium.MyBoosts.model_rebuild()
types.premium.BoostsStatus.model_rebuild()
types.smsjobs.EligibleToJoin.model_rebuild()
types.smsjobs.Status.model_rebuild()
types.fragment.CollectibleInfo.model_rebuild()



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InstallTheme(BaseModel):
    """
    functions.account.InstallTheme
    ID: 0xc727bb3b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.InstallTheme', 'InstallTheme'] = pydantic.Field(
        'functions.account.InstallTheme',
        alias='_'
    )

    dark: typing.Optional[bool] = None
    theme: typing.Optional["base.InputTheme"] = None
    format: typing.Optional[str] = None
    base_theme: typing.Optional["base.BaseTheme"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetBroadcastRevenueWithdrawalUrl(BaseModel):
    """
    functions.stats.GetBroadcastRevenueWithdrawalUrl
    ID: 0x2a65ef73
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stats.GetBroadcastRevenueWithdrawalUrl', 'GetBroadcastRevenueWithdrawalUrl'] = pydantic.Field(
        'functions.stats.GetBroadcastRevenueWithdrawalUrl',
        alias='_'
    )

    channel: "base.InputChannel"
    password: "base.InputCheckPasswordSRP"
